Class: Aws::SSOAdmin::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SSOAdmin::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ssoadmin/client.rb
Overview
An API client for SSOAdmin. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::SSOAdmin::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_region(params = {}) ⇒ Types::AddRegionResponse
Adds a Region to an IAM Identity Center instance.
-
#attach_customer_managed_policy_reference_to_permission_set(params = {}) ⇒ Struct
Attaches the specified customer managed policy to the specified PermissionSet.
-
#attach_managed_policy_to_permission_set(params = {}) ⇒ Struct
Attaches an Amazon Web Services managed policy ARN to a permission set.
-
#create_account_assignment(params = {}) ⇒ Types::CreateAccountAssignmentResponse
Assigns access to a principal for a specified Amazon Web Services account using a specified permission set.
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an OAuth 2.0 customer managed application in IAM Identity Center for the given application provider.
-
#create_application_assignment(params = {}) ⇒ Struct
Grant application access to a user or group.
-
#create_instance(params = {}) ⇒ Types::CreateInstanceResponse
Creates an instance of IAM Identity Center for a standalone Amazon Web Services account that is not managed by Organizations or a member Amazon Web Services account in an organization.
-
#create_instance_access_control_attribute_configuration(params = {}) ⇒ Struct
Enables the attributes-based access control (ABAC) feature for the specified IAM Identity Center instance.
-
#create_permission_set(params = {}) ⇒ Types::CreatePermissionSetResponse
Creates a permission set within a specified IAM Identity Center instance.
-
#create_trusted_token_issuer(params = {}) ⇒ Types::CreateTrustedTokenIssuerResponse
Creates a connection to a trusted token issuer in an instance of IAM Identity Center.
-
#delete_account_assignment(params = {}) ⇒ Types::DeleteAccountAssignmentResponse
Deletes a principal’s access from a specified Amazon Web Services account using a specified permission set.
-
#delete_application(params = {}) ⇒ Struct
Deletes the association with the application.
-
#delete_application_access_scope(params = {}) ⇒ Struct
Deletes an IAM Identity Center access scope from an application.
-
#delete_application_assignment(params = {}) ⇒ Struct
Revoke application access to an application by deleting application assignments for a user or group.
-
#delete_application_authentication_method(params = {}) ⇒ Struct
Deletes an authentication method from an application.
-
#delete_application_grant(params = {}) ⇒ Struct
Deletes a grant from an application.
-
#delete_inline_policy_from_permission_set(params = {}) ⇒ Struct
Deletes the inline policy from a specified permission set.
-
#delete_instance(params = {}) ⇒ Struct
Deletes the instance of IAM Identity Center.
-
#delete_instance_access_control_attribute_configuration(params = {}) ⇒ Struct
Disables the attributes-based access control (ABAC) feature for the specified IAM Identity Center instance and deletes all of the attribute mappings that have been configured.
-
#delete_permission_set(params = {}) ⇒ Struct
Deletes the specified permission set.
-
#delete_permissions_boundary_from_permission_set(params = {}) ⇒ Struct
Deletes the permissions boundary from a specified PermissionSet.
-
#delete_trusted_token_issuer(params = {}) ⇒ Struct
Deletes a trusted token issuer configuration from an instance of IAM Identity Center.
-
#describe_account_assignment_creation_status(params = {}) ⇒ Types::DescribeAccountAssignmentCreationStatusResponse
Describes the status of the assignment creation request.
-
#describe_account_assignment_deletion_status(params = {}) ⇒ Types::DescribeAccountAssignmentDeletionStatusResponse
Describes the status of the assignment deletion request.
-
#describe_application(params = {}) ⇒ Types::DescribeApplicationResponse
Retrieves the details of an application associated with an instance of IAM Identity Center.
-
#describe_application_assignment(params = {}) ⇒ Types::DescribeApplicationAssignmentResponse
Retrieves a direct assignment of a user or group to an application.
-
#describe_application_provider(params = {}) ⇒ Types::DescribeApplicationProviderResponse
Retrieves details about a provider that can be used to connect an Amazon Web Services managed application or customer managed application to IAM Identity Center.
-
#describe_instance(params = {}) ⇒ Types::DescribeInstanceResponse
Returns the details of an instance of IAM Identity Center.
-
#describe_instance_access_control_attribute_configuration(params = {}) ⇒ Types::DescribeInstanceAccessControlAttributeConfigurationResponse
Returns the list of IAM Identity Center identity store attributes that have been configured to work with attributes-based access control (ABAC) for the specified IAM Identity Center instance.
-
#describe_permission_set(params = {}) ⇒ Types::DescribePermissionSetResponse
Gets the details of the permission set.
-
#describe_permission_set_provisioning_status(params = {}) ⇒ Types::DescribePermissionSetProvisioningStatusResponse
Describes the status for the given permission set provisioning request.
-
#describe_region(params = {}) ⇒ Types::DescribeRegionResponse
Retrieves details about a specific Region enabled in an IAM Identity Center instance.
-
#describe_trusted_token_issuer(params = {}) ⇒ Types::DescribeTrustedTokenIssuerResponse
Retrieves details about a trusted token issuer configuration stored in an instance of IAM Identity Center.
-
#detach_customer_managed_policy_reference_from_permission_set(params = {}) ⇒ Struct
Detaches the specified customer managed policy from the specified PermissionSet.
-
#detach_managed_policy_from_permission_set(params = {}) ⇒ Struct
Detaches the attached Amazon Web Services managed policy ARN from the specified permission set.
-
#get_application_access_scope(params = {}) ⇒ Types::GetApplicationAccessScopeResponse
Retrieves the authorized targets for an IAM Identity Center access scope for an application.
-
#get_application_assignment_configuration(params = {}) ⇒ Types::GetApplicationAssignmentConfigurationResponse
Retrieves the configuration of PutApplicationAssignmentConfiguration.
-
#get_application_authentication_method(params = {}) ⇒ Types::GetApplicationAuthenticationMethodResponse
Retrieves details about an authentication method used by an application.
-
#get_application_grant(params = {}) ⇒ Types::GetApplicationGrantResponse
Retrieves details about an application grant.
-
#get_application_session_configuration(params = {}) ⇒ Types::GetApplicationSessionConfigurationResponse
Retrieves the session configuration for an application in IAM Identity Center.
-
#get_inline_policy_for_permission_set(params = {}) ⇒ Types::GetInlinePolicyForPermissionSetResponse
Obtains the inline policy assigned to the permission set.
-
#get_permissions_boundary_for_permission_set(params = {}) ⇒ Types::GetPermissionsBoundaryForPermissionSetResponse
Obtains the permissions boundary for a specified PermissionSet.
-
#list_account_assignment_creation_status(params = {}) ⇒ Types::ListAccountAssignmentCreationStatusResponse
Lists the status of the Amazon Web Services account assignment creation requests for a specified IAM Identity Center instance.
-
#list_account_assignment_deletion_status(params = {}) ⇒ Types::ListAccountAssignmentDeletionStatusResponse
Lists the status of the Amazon Web Services account assignment deletion requests for a specified IAM Identity Center instance.
-
#list_account_assignments(params = {}) ⇒ Types::ListAccountAssignmentsResponse
Lists the assignee of the specified Amazon Web Services account with the specified permission set.
-
#list_account_assignments_for_principal(params = {}) ⇒ Types::ListAccountAssignmentsForPrincipalResponse
Retrieves a list of the IAM Identity Center associated Amazon Web Services accounts that the principal has access to.
-
#list_accounts_for_provisioned_permission_set(params = {}) ⇒ Types::ListAccountsForProvisionedPermissionSetResponse
Lists all the Amazon Web Services accounts where the specified permission set is provisioned.
-
#list_application_access_scopes(params = {}) ⇒ Types::ListApplicationAccessScopesResponse
Lists the access scopes and authorized targets associated with an application.
-
#list_application_assignments(params = {}) ⇒ Types::ListApplicationAssignmentsResponse
Lists Amazon Web Services account users that are assigned to an application.
-
#list_application_assignments_for_principal(params = {}) ⇒ Types::ListApplicationAssignmentsForPrincipalResponse
Lists the applications to which a specified principal is assigned.
-
#list_application_authentication_methods(params = {}) ⇒ Types::ListApplicationAuthenticationMethodsResponse
Lists all of the authentication methods supported by the specified application.
-
#list_application_grants(params = {}) ⇒ Types::ListApplicationGrantsResponse
List the grants associated with an application.
-
#list_application_providers(params = {}) ⇒ Types::ListApplicationProvidersResponse
Lists the application providers configured in the IAM Identity Center identity store.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists all applications associated with the instance of IAM Identity Center.
-
#list_customer_managed_policy_references_in_permission_set(params = {}) ⇒ Types::ListCustomerManagedPolicyReferencesInPermissionSetResponse
Lists all customer managed policies attached to a specified PermissionSet.
-
#list_instances(params = {}) ⇒ Types::ListInstancesResponse
Lists the details of the organization and account instances of IAM Identity Center that were created in or visible to the account calling this API.
-
#list_managed_policies_in_permission_set(params = {}) ⇒ Types::ListManagedPoliciesInPermissionSetResponse
Lists the Amazon Web Services managed policy that is attached to a specified permission set.
-
#list_permission_set_provisioning_status(params = {}) ⇒ Types::ListPermissionSetProvisioningStatusResponse
Lists the status of the permission set provisioning requests for a specified IAM Identity Center instance.
-
#list_permission_sets(params = {}) ⇒ Types::ListPermissionSetsResponse
Lists the PermissionSets in an IAM Identity Center instance.
-
#list_permission_sets_provisioned_to_account(params = {}) ⇒ Types::ListPermissionSetsProvisionedToAccountResponse
Lists all the permission sets that are provisioned to a specified Amazon Web Services account.
-
#list_regions(params = {}) ⇒ Types::ListRegionsResponse
Lists all enabled Regions of an IAM Identity Center instance, including those that are being added or removed.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags that are attached to a specified resource.
-
#list_trusted_token_issuers(params = {}) ⇒ Types::ListTrustedTokenIssuersResponse
Lists all the trusted token issuers configured in an instance of IAM Identity Center.
-
#provision_permission_set(params = {}) ⇒ Types::ProvisionPermissionSetResponse
The process by which a specified permission set is provisioned to the specified target.
-
#put_application_access_scope(params = {}) ⇒ Struct
Adds or updates the list of authorized targets for an IAM Identity Center access scope for an application.
-
#put_application_assignment_configuration(params = {}) ⇒ Struct
Configure how users gain access to an application.
-
#put_application_authentication_method(params = {}) ⇒ Struct
Adds or updates an authentication method for an application.
-
#put_application_grant(params = {}) ⇒ Struct
Creates a configuration for an application to use grants.
-
#put_application_session_configuration(params = {}) ⇒ Struct
Updates the session configuration for an application in IAM Identity Center.
-
#put_inline_policy_to_permission_set(params = {}) ⇒ Struct
Attaches an inline policy to a permission set.
-
#put_permissions_boundary_to_permission_set(params = {}) ⇒ Struct
Attaches an Amazon Web Services managed or customer managed policy to the specified PermissionSet as a permissions boundary.
-
#remove_region(params = {}) ⇒ Types::RemoveRegionResponse
Removes an additional Region from an IAM Identity Center instance.
-
#tag_resource(params = {}) ⇒ Struct
Associates a set of tags with a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Disassociates a set of tags from a specified resource.
-
#update_application(params = {}) ⇒ Struct
Updates application properties.
-
#update_instance(params = {}) ⇒ Struct
Update the details for the instance of IAM Identity Center that is owned by the Amazon Web Services account.
-
#update_instance_access_control_attribute_configuration(params = {}) ⇒ Struct
Updates the IAM Identity Center identity store attributes that you can use with the IAM Identity Center instance for attributes-based access control (ABAC).
-
#update_permission_set(params = {}) ⇒ Struct
Updates an existing permission set.
-
#update_trusted_token_issuer(params = {}) ⇒ Struct
Updates the name of the trusted token issuer, or the path of a source attribute or destination attribute for a trusted token issuer configuration.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4334 4335 4336 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 4334 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4337 4338 4339 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 4337 def errors_module Errors end |
Instance Method Details
#add_region(params = {}) ⇒ Types::AddRegionResponse
Adds a Region to an IAM Identity Center instance. This operation initiates an asynchronous workflow to replicate the IAM Identity Center instance to the target Region. The Region status is set to ADDING at first and changes to ACTIVE when the workflow completes.
To use this operation, your IAM Identity Center instance and the target Region must meet the requirements described in the [IAM Identity Center User Guide].
The following actions are related to ‘AddRegion`:
- RemoveRegion][2
- DescribeRegion][3
- ListRegions][4
[1]: docs.aws.amazon.com/singlesignon/latest/userguide/multi-region-iam-identity-center.html#multi-region-prerequisites [2]: docs.aws.amazon.com/singlesignon/latest/APIReference/API_RemoveRegion.html [3]: docs.aws.amazon.com/singlesignon/latest/APIReference/API_DescribeRegion.html [4]: docs.aws.amazon.com/singlesignon/latest/APIReference/API_ListRegions.html
539 540 541 542 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 539 def add_region(params = {}, = {}) req = build_request(:add_region, params) req.send_request() end |
#attach_customer_managed_policy_reference_to_permission_set(params = {}) ⇒ Struct
Attaches the specified customer managed policy to the specified PermissionSet.
576 577 578 579 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 576 def (params = {}, = {}) req = build_request(:attach_customer_managed_policy_reference_to_permission_set, params) req.send_request() end |
#attach_managed_policy_to_permission_set(params = {}) ⇒ Struct
Attaches an Amazon Web Services managed policy ARN to a permission set.
<note markdown=“1”> If the permission set is already referenced by one or more account assignments, you will need to call ‘ ProvisionPermissionSet ` after this operation. Calling `ProvisionPermissionSet` applies the corresponding IAM policy updates to all assigned accounts.
</note>
620 621 622 623 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 620 def (params = {}, = {}) req = build_request(:attach_managed_policy_to_permission_set, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4307 4308 4309 4310 4311 4312 4313 4314 4315 4316 4317 4318 4319 4320 4321 4322 4323 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 4307 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SSOAdmin') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ssoadmin' context[:gem_version] = '1.71.0' Seahorse::Client::Request.new(handlers, context) end |
#create_account_assignment(params = {}) ⇒ Types::CreateAccountAssignmentResponse
Assigns access to a principal for a specified Amazon Web Services account using a specified permission set.
<note markdown=“1”> The term principal here refers to a user or group that is defined in IAM Identity Center.
</note>
<note markdown=“1”> As part of a successful ‘CreateAccountAssignment` call, the specified permission set will automatically be provisioned to the account in the form of an IAM policy. That policy is attached to the IAM role created in IAM Identity Center. If the permission set is subsequently updated, the corresponding IAM policies attached to roles in your accounts will not be updated automatically. In this case, you must call ` ProvisionPermissionSet ` to make these updates.
</note>
<note markdown=“1”> After a successful response, call ‘DescribeAccountAssignmentCreationStatus` to describe the status of an assignment creation request.
</note>
709 710 711 712 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 709 def create_account_assignment(params = {}, = {}) req = build_request(:create_account_assignment, params) req.send_request() end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an OAuth 2.0 customer managed application in IAM Identity Center for the given application provider.
<note markdown=“1”> This API does not support creating SAML 2.0 customer managed applications or Amazon Web Services managed applications. To learn how to create an Amazon Web Services managed application, see the application user guide. You can create a SAML 2.0 customer managed application in the Amazon Web Services Management Console only. See [Setting up customer managed SAML 2.0 applications]. For more information on these application types, see [Amazon Web Services managed applications].
</note>
[1]: docs.aws.amazon.com/singlesignon/latest/userguide/customermanagedapps-saml2-setup.html [2]: docs.aws.amazon.com/singlesignon/latest/userguide/awsapps.html
822 823 824 825 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 822 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_application_assignment(params = {}) ⇒ Struct
Grant application access to a user or group.
860 861 862 863 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 860 def create_application_assignment(params = {}, = {}) req = build_request(:create_application_assignment, params) req.send_request() end |
#create_instance(params = {}) ⇒ Types::CreateInstanceResponse
Creates an instance of IAM Identity Center for a standalone Amazon Web Services account that is not managed by Organizations or a member Amazon Web Services account in an organization. You can create only one instance per account and across all Amazon Web Services Regions.
The CreateInstance request is rejected if the following apply:
-
The instance is created within the organization management account.
-
An instance already exists in the same account.
929 930 931 932 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 929 def create_instance(params = {}, = {}) req = build_request(:create_instance, params) req.send_request() end |
#create_instance_access_control_attribute_configuration(params = {}) ⇒ Struct
Enables the attributes-based access control (ABAC) feature for the specified IAM Identity Center instance. You can also specify new attributes to add to your ABAC configuration during the enabling process. For more information about ABAC, see [Attribute-Based Access Control](/singlesignon/latest/userguide/abac.html) in the *IAM Identity Center User Guide*.
<note markdown=“1”> After a successful response, call ‘DescribeInstanceAccessControlAttributeConfiguration` to validate that `InstanceAccessControlAttributeConfiguration` was created.
</note>
983 984 985 986 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 983 def create_instance_access_control_attribute_configuration(params = {}, = {}) req = build_request(:create_instance_access_control_attribute_configuration, params) req.send_request() end |
#create_permission_set(params = {}) ⇒ Types::CreatePermissionSetResponse
Creates a permission set within a specified IAM Identity Center instance.
<note markdown=“1”> To grant users and groups access to Amazon Web Services account resources, use ‘ CreateAccountAssignment `.
</note>
1053 1054 1055 1056 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1053 def (params = {}, = {}) req = build_request(:create_permission_set, params) req.send_request() end |
#create_trusted_token_issuer(params = {}) ⇒ Types::CreateTrustedTokenIssuerResponse
Creates a connection to a trusted token issuer in an instance of IAM Identity Center. A trusted token issuer enables trusted identity propagation to be used with applications that authenticate outside of Amazon Web Services.
This trusted token issuer describes an external identity provider (IdP) that can generate claims or assertions in the form of access tokens for a user. Applications enabled for IAM Identity Center can use these tokens for authentication.
1144 1145 1146 1147 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1144 def create_trusted_token_issuer(params = {}, = {}) req = build_request(:create_trusted_token_issuer, params) req.send_request() end |
#delete_account_assignment(params = {}) ⇒ Types::DeleteAccountAssignmentResponse
Deletes a principal’s access from a specified Amazon Web Services account using a specified permission set.
<note markdown=“1”> After a successful response, call ‘DescribeAccountAssignmentDeletionStatus` to describe the status of an assignment deletion request.
</note>
1217 1218 1219 1220 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1217 def delete_account_assignment(params = {}, = {}) req = build_request(:delete_account_assignment, params) req.send_request() end |
#delete_application(params = {}) ⇒ Struct
Deletes the association with the application. The connected service resource still exists.
1243 1244 1245 1246 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1243 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_application_access_scope(params = {}) ⇒ Struct
Deletes an IAM Identity Center access scope from an application.
1269 1270 1271 1272 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1269 def delete_application_access_scope(params = {}, = {}) req = build_request(:delete_application_access_scope, params) req.send_request() end |
#delete_application_assignment(params = {}) ⇒ Struct
Revoke application access to an application by deleting application assignments for a user or group.
1308 1309 1310 1311 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1308 def delete_application_assignment(params = {}, = {}) req = build_request(:delete_application_assignment, params) req.send_request() end |
#delete_application_authentication_method(params = {}) ⇒ Struct
Deletes an authentication method from an application.
1336 1337 1338 1339 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1336 def delete_application_authentication_method(params = {}, = {}) req = build_request(:delete_application_authentication_method, params) req.send_request() end |
#delete_application_grant(params = {}) ⇒ Struct
Deletes a grant from an application.
1362 1363 1364 1365 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1362 def delete_application_grant(params = {}, = {}) req = build_request(:delete_application_grant, params) req.send_request() end |
#delete_inline_policy_from_permission_set(params = {}) ⇒ Struct
Deletes the inline policy from a specified permission set.
1392 1393 1394 1395 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1392 def (params = {}, = {}) req = build_request(:delete_inline_policy_from_permission_set, params) req.send_request() end |
#delete_instance(params = {}) ⇒ Struct
Deletes the instance of IAM Identity Center. Only the account that owns the instance can call this API. Neither the delegated administrator nor member account can delete the organization instance, but those roles can delete their own instance.
1418 1419 1420 1421 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1418 def delete_instance(params = {}, = {}) req = build_request(:delete_instance, params) req.send_request() end |
#delete_instance_access_control_attribute_configuration(params = {}) ⇒ Struct
Disables the attributes-based access control (ABAC) feature for the specified IAM Identity Center instance and deletes all of the attribute mappings that have been configured. Once deleted, any attributes that are received from an identity source and any custom attributes you have previously configured will not be passed. For more information about ABAC, see [Attribute-Based Access Control](/singlesignon/latest/userguide/abac.html) in the *IAM Identity Center User Guide*.
1448 1449 1450 1451 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1448 def delete_instance_access_control_attribute_configuration(params = {}, = {}) req = build_request(:delete_instance_access_control_attribute_configuration, params) req.send_request() end |
#delete_permission_set(params = {}) ⇒ Struct
Deletes the specified permission set.
1478 1479 1480 1481 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1478 def (params = {}, = {}) req = build_request(:delete_permission_set, params) req.send_request() end |
#delete_permissions_boundary_from_permission_set(params = {}) ⇒ Struct
Deletes the permissions boundary from a specified PermissionSet.
1505 1506 1507 1508 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1505 def (params = {}, = {}) req = build_request(:delete_permissions_boundary_from_permission_set, params) req.send_request() end |
#delete_trusted_token_issuer(params = {}) ⇒ Struct
Deletes a trusted token issuer configuration from an instance of IAM Identity Center.
<note markdown=“1”> Deleting this trusted token issuer configuration will cause users to lose access to any applications that are configured to use the trusted token issuer.
</note>
1534 1535 1536 1537 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1534 def delete_trusted_token_issuer(params = {}, = {}) req = build_request(:delete_trusted_token_issuer, params) req.send_request() end |
#describe_account_assignment_creation_status(params = {}) ⇒ Types::DescribeAccountAssignmentCreationStatusResponse
Describes the status of the assignment creation request.
1578 1579 1580 1581 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1578 def describe_account_assignment_creation_status(params = {}, = {}) req = build_request(:describe_account_assignment_creation_status, params) req.send_request() end |
#describe_account_assignment_deletion_status(params = {}) ⇒ Types::DescribeAccountAssignmentDeletionStatusResponse
Describes the status of the assignment deletion request.
1622 1623 1624 1625 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1622 def describe_account_assignment_deletion_status(params = {}, = {}) req = build_request(:describe_account_assignment_deletion_status, params) req.send_request() end |
#describe_application(params = {}) ⇒ Types::DescribeApplicationResponse
Retrieves the details of an application associated with an instance of IAM Identity Center.
1676 1677 1678 1679 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1676 def describe_application(params = {}, = {}) req = build_request(:describe_application, params) req.send_request() end |
#describe_application_assignment(params = {}) ⇒ Types::DescribeApplicationAssignmentResponse
Retrieves a direct assignment of a user or group to an application. If the user doesn’t have a direct assignment to the application, the user may still have access to the application through a group. Therefore, don’t use this API to test access to an application for a user. Instead use ListApplicationAssignmentsForPrincipal.
1731 1732 1733 1734 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1731 def describe_application_assignment(params = {}, = {}) req = build_request(:describe_application_assignment, params) req.send_request() end |
#describe_application_provider(params = {}) ⇒ Types::DescribeApplicationProviderResponse
Retrieves details about a provider that can be used to connect an Amazon Web Services managed application or customer managed application to IAM Identity Center.
1772 1773 1774 1775 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1772 def describe_application_provider(params = {}, = {}) req = build_request(:describe_application_provider, params) req.send_request() end |
#describe_instance(params = {}) ⇒ Types::DescribeInstanceResponse
Returns the details of an instance of IAM Identity Center. The status can be one of the following:
-
‘CREATE_IN_PROGRESS` - The instance is in the process of being created. When the instance is ready for use, DescribeInstance returns the status of `ACTIVE`. While the instance is in the `CREATE_IN_PROGRESS` state, you can call only DescribeInstance and DeleteInstance operations.
-
‘DELETE_IN_PROGRESS` - The instance is being deleted. Returns `AccessDeniedException` after the delete operation completes.
-
‘ACTIVE` - The instance is active.
1830 1831 1832 1833 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1830 def describe_instance(params = {}, = {}) req = build_request(:describe_instance, params) req.send_request() end |
#describe_instance_access_control_attribute_configuration(params = {}) ⇒ Types::DescribeInstanceAccessControlAttributeConfigurationResponse
Returns the list of IAM Identity Center identity store attributes that have been configured to work with attributes-based access control (ABAC) for the specified IAM Identity Center instance. This will not return attributes configured and sent by an external identity provider. For more information about ABAC, see [Attribute-Based Access Control](/singlesignon/latest/userguide/abac.html) in the *IAM Identity Center User Guide*.
1872 1873 1874 1875 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1872 def describe_instance_access_control_attribute_configuration(params = {}, = {}) req = build_request(:describe_instance_access_control_attribute_configuration, params) req.send_request() end |
#describe_permission_set(params = {}) ⇒ Types::DescribePermissionSetResponse
Gets the details of the permission set.
1913 1914 1915 1916 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1913 def (params = {}, = {}) req = build_request(:describe_permission_set, params) req.send_request() end |
#describe_permission_set_provisioning_status(params = {}) ⇒ Types::DescribePermissionSetProvisioningStatusResponse
Describes the status for the given permission set provisioning request.
1956 1957 1958 1959 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 1956 def (params = {}, = {}) req = build_request(:describe_permission_set_provisioning_status, params) req.send_request() end |
#describe_region(params = {}) ⇒ Types::DescribeRegionResponse
Retrieves details about a specific Region enabled in an IAM Identity Center instance. Details include the Region name, current status (ACTIVE, ADDING, or REMOVING), the date when the Region was added, and whether it is the primary Region. The request must be made from one of the enabled Regions of the IAM Identity Center instance.
The following actions are related to ‘DescribeRegion`:
- AddRegion][1
- RemoveRegion][2
- ListRegions][3
[1]: docs.aws.amazon.com/singlesignon/latest/APIReference/API_AddRegion.html [2]: docs.aws.amazon.com/singlesignon/latest/APIReference/API_RemoveRegion.html [3]: docs.aws.amazon.com/singlesignon/latest/APIReference/API_ListRegions.html
2014 2015 2016 2017 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2014 def describe_region(params = {}, = {}) req = build_request(:describe_region, params) req.send_request() end |
#describe_trusted_token_issuer(params = {}) ⇒ Types::DescribeTrustedTokenIssuerResponse
Retrieves details about a trusted token issuer configuration stored in an instance of IAM Identity Center. Details include the name of the trusted token issuer, the issuer URL, and the path of the source attribute and the destination attribute for a trusted token issuer configuration.
2056 2057 2058 2059 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2056 def describe_trusted_token_issuer(params = {}, = {}) req = build_request(:describe_trusted_token_issuer, params) req.send_request() end |
#detach_customer_managed_policy_reference_from_permission_set(params = {}) ⇒ Struct
Detaches the specified customer managed policy from the specified PermissionSet.
2093 2094 2095 2096 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2093 def (params = {}, = {}) req = build_request(:detach_customer_managed_policy_reference_from_permission_set, params) req.send_request() end |
#detach_managed_policy_from_permission_set(params = {}) ⇒ Struct
Detaches the attached Amazon Web Services managed policy ARN from the specified permission set.
2129 2130 2131 2132 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2129 def (params = {}, = {}) req = build_request(:detach_managed_policy_from_permission_set, params) req.send_request() end |
#get_application_access_scope(params = {}) ⇒ Types::GetApplicationAccessScopeResponse
Retrieves the authorized targets for an IAM Identity Center access scope for an application.
2167 2168 2169 2170 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2167 def get_application_access_scope(params = {}, = {}) req = build_request(:get_application_access_scope, params) req.send_request() end |
#get_application_assignment_configuration(params = {}) ⇒ Types::GetApplicationAssignmentConfigurationResponse
Retrieves the configuration of PutApplicationAssignmentConfiguration.
2198 2199 2200 2201 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2198 def get_application_assignment_configuration(params = {}, = {}) req = build_request(:get_application_assignment_configuration, params) req.send_request() end |
#get_application_authentication_method(params = {}) ⇒ Types::GetApplicationAuthenticationMethodResponse
Retrieves details about an authentication method used by an application.
2232 2233 2234 2235 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2232 def get_application_authentication_method(params = {}, = {}) req = build_request(:get_application_authentication_method, params) req.send_request() end |
#get_application_grant(params = {}) ⇒ Types::GetApplicationGrantResponse
Retrieves details about an application grant.
2269 2270 2271 2272 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2269 def get_application_grant(params = {}, = {}) req = build_request(:get_application_grant, params) req.send_request() end |
#get_application_session_configuration(params = {}) ⇒ Types::GetApplicationSessionConfigurationResponse
Retrieves the session configuration for an application in IAM Identity Center.
The session configuration determines how users can access an application. This includes whether user background sessions are enabled. User background sessions allow users to start a job on a supported Amazon Web Services managed application without having to remain signed in to an active session while the job runs.
2305 2306 2307 2308 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2305 def get_application_session_configuration(params = {}, = {}) req = build_request(:get_application_session_configuration, params) req.send_request() end |
#get_inline_policy_for_permission_set(params = {}) ⇒ Types::GetInlinePolicyForPermissionSetResponse
Obtains the inline policy assigned to the permission set.
2341 2342 2343 2344 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2341 def (params = {}, = {}) req = build_request(:get_inline_policy_for_permission_set, params) req.send_request() end |
#get_permissions_boundary_for_permission_set(params = {}) ⇒ Types::GetPermissionsBoundaryForPermissionSetResponse
Obtains the permissions boundary for a specified PermissionSet.
2376 2377 2378 2379 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2376 def (params = {}, = {}) req = build_request(:get_permissions_boundary_for_permission_set, params) req.send_request() end |
#list_account_assignment_creation_status(params = {}) ⇒ Types::ListAccountAssignmentCreationStatusResponse
Lists the status of the Amazon Web Services account assignment creation requests for a specified IAM Identity Center instance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2431 2432 2433 2434 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2431 def list_account_assignment_creation_status(params = {}, = {}) req = build_request(:list_account_assignment_creation_status, params) req.send_request() end |
#list_account_assignment_deletion_status(params = {}) ⇒ Types::ListAccountAssignmentDeletionStatusResponse
Lists the status of the Amazon Web Services account assignment deletion requests for a specified IAM Identity Center instance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2486 2487 2488 2489 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2486 def list_account_assignment_deletion_status(params = {}, = {}) req = build_request(:list_account_assignment_deletion_status, params) req.send_request() end |
#list_account_assignments(params = {}) ⇒ Types::ListAccountAssignmentsResponse
Lists the assignee of the specified Amazon Web Services account with the specified permission set.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2545 2546 2547 2548 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2545 def list_account_assignments(params = {}, = {}) req = build_request(:list_account_assignments, params) req.send_request() end |
#list_account_assignments_for_principal(params = {}) ⇒ Types::ListAccountAssignmentsForPrincipalResponse
Retrieves a list of the IAM Identity Center associated Amazon Web Services accounts that the principal has access to. This action must be called from the management account containing your organization instance of IAM Identity Center. This action is not valid for account instances of IAM Identity Center.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2621 2622 2623 2624 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2621 def list_account_assignments_for_principal(params = {}, = {}) req = build_request(:list_account_assignments_for_principal, params) req.send_request() end |
#list_accounts_for_provisioned_permission_set(params = {}) ⇒ Types::ListAccountsForProvisionedPermissionSetResponse
Lists all the Amazon Web Services accounts where the specified permission set is provisioned.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2678 2679 2680 2681 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2678 def (params = {}, = {}) req = build_request(:list_accounts_for_provisioned_permission_set, params) req.send_request() end |
#list_application_access_scopes(params = {}) ⇒ Types::ListApplicationAccessScopesResponse
Lists the access scopes and authorized targets associated with an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2733 2734 2735 2736 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2733 def list_application_access_scopes(params = {}, = {}) req = build_request(:list_application_access_scopes, params) req.send_request() end |
#list_application_assignments(params = {}) ⇒ Types::ListApplicationAssignmentsResponse
Lists Amazon Web Services account users that are assigned to an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2788 2789 2790 2791 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2788 def list_application_assignments(params = {}, = {}) req = build_request(:list_application_assignments, params) req.send_request() end |
#list_application_assignments_for_principal(params = {}) ⇒ Types::ListApplicationAssignmentsForPrincipalResponse
Lists the applications to which a specified principal is assigned. You must provide a filter when calling this action from a member account against your organization instance of IAM Identity Center. A filter is not required when called from the management account against an organization instance of IAM Identity Center, or from a member account against an account instance of IAM Identity Center in the same account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2866 2867 2868 2869 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2866 def list_application_assignments_for_principal(params = {}, = {}) req = build_request(:list_application_assignments_for_principal, params) req.send_request() end |
#list_application_authentication_methods(params = {}) ⇒ Types::ListApplicationAuthenticationMethodsResponse
Lists all of the authentication methods supported by the specified application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2909 2910 2911 2912 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2909 def list_application_authentication_methods(params = {}, = {}) req = build_request(:list_application_authentication_methods, params) req.send_request() end |
#list_application_grants(params = {}) ⇒ Types::ListApplicationGrantsResponse
List the grants associated with an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2956 2957 2958 2959 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 2956 def list_application_grants(params = {}, = {}) req = build_request(:list_application_grants, params) req.send_request() end |
#list_application_providers(params = {}) ⇒ Types::ListApplicationProvidersResponse
Lists the application providers configured in the IAM Identity Center identity store.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3012 3013 3014 3015 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3012 def list_application_providers(params = {}, = {}) req = build_request(:list_application_providers, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists all applications associated with the instance of IAM Identity Center. When listing applications for an organization instance in the management account, member accounts must use the ‘applicationAccount` parameter to filter the list to only applications created from that account. When listing applications for an account instance in the same member account, a filter is not required.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3092 3093 3094 3095 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3092 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#list_customer_managed_policy_references_in_permission_set(params = {}) ⇒ Types::ListCustomerManagedPolicyReferencesInPermissionSetResponse
Lists all customer managed policies attached to a specified PermissionSet.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3141 3142 3143 3144 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3141 def (params = {}, = {}) req = build_request(:list_customer_managed_policy_references_in_permission_set, params) req.send_request() end |
#list_instances(params = {}) ⇒ Types::ListInstancesResponse
Lists the details of the organization and account instances of IAM Identity Center that were created in or visible to the account calling this API.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3187 3188 3189 3190 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3187 def list_instances(params = {}, = {}) req = build_request(:list_instances, params) req.send_request() end |
#list_managed_policies_in_permission_set(params = {}) ⇒ Types::ListManagedPoliciesInPermissionSetResponse
Lists the Amazon Web Services managed policy that is attached to a specified permission set.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3239 3240 3241 3242 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3239 def (params = {}, = {}) req = build_request(:list_managed_policies_in_permission_set, params) req.send_request() end |
#list_permission_set_provisioning_status(params = {}) ⇒ Types::ListPermissionSetProvisioningStatusResponse
Lists the status of the permission set provisioning requests for a specified IAM Identity Center instance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3294 3295 3296 3297 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3294 def (params = {}, = {}) req = build_request(:list_permission_set_provisioning_status, params) req.send_request() end |
#list_permission_sets(params = {}) ⇒ Types::ListPermissionSetsResponse
Lists the PermissionSets in an IAM Identity Center instance.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3340 3341 3342 3343 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3340 def (params = {}, = {}) req = build_request(:list_permission_sets, params) req.send_request() end |
#list_permission_sets_provisioned_to_account(params = {}) ⇒ Types::ListPermissionSetsProvisionedToAccountResponse
Lists all the permission sets that are provisioned to a specified Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3396 3397 3398 3399 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3396 def (params = {}, = {}) req = build_request(:list_permission_sets_provisioned_to_account, params) req.send_request() end |
#list_regions(params = {}) ⇒ Types::ListRegionsResponse
Lists all enabled Regions of an IAM Identity Center instance, including those that are being added or removed. This operation returns Regions with ACTIVE, ADDING, or REMOVING status.
The following actions are related to ‘ListRegions`:
- AddRegion][1
- RemoveRegion][2
- DescribeRegion][3
[1]: docs.aws.amazon.com/singlesignon/latest/APIReference/API_AddRegion.html [2]: docs.aws.amazon.com/singlesignon/latest/APIReference/API_RemoveRegion.html [3]: docs.aws.amazon.com/singlesignon/latest/APIReference/API_DescribeRegion.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3458 3459 3460 3461 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3458 def list_regions(params = {}, = {}) req = build_request(:list_regions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags that are attached to a specified resource.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3505 3506 3507 3508 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3505 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_trusted_token_issuers(params = {}) ⇒ Types::ListTrustedTokenIssuersResponse
Lists all the trusted token issuers configured in an instance of IAM Identity Center.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3561 3562 3563 3564 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3561 def list_trusted_token_issuers(params = {}, = {}) req = build_request(:list_trusted_token_issuers, params) req.send_request() end |
#provision_permission_set(params = {}) ⇒ Types::ProvisionPermissionSetResponse
The process by which a specified permission set is provisioned to the specified target.
3612 3613 3614 3615 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3612 def (params = {}, = {}) req = build_request(:provision_permission_set, params) req.send_request() end |
#put_application_access_scope(params = {}) ⇒ Struct
Adds or updates the list of authorized targets for an IAM Identity Center access scope for an application.
3646 3647 3648 3649 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3646 def put_application_access_scope(params = {}, = {}) req = build_request(:put_application_access_scope, params) req.send_request() end |
#put_application_assignment_configuration(params = {}) ⇒ Struct
Configure how users gain access to an application. If ‘AssignmentsRequired` is `true` (default value), users don’t have access to the application unless an assignment is created using the [CreateApplicationAssignment API]. If `false`, all users have access to the application. If an assignment is created using [CreateApplicationAssignment]., the user retains access if `AssignmentsRequired` is set to `true`.
[1]: docs.aws.amazon.com/singlesignon/latest/APIReference/API_CreateApplicationAssignment.html
3692 3693 3694 3695 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3692 def put_application_assignment_configuration(params = {}, = {}) req = build_request(:put_application_assignment_configuration, params) req.send_request() end |
#put_application_authentication_method(params = {}) ⇒ Struct
Adds or updates an authentication method for an application.
3731 3732 3733 3734 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3731 def put_application_authentication_method(params = {}, = {}) req = build_request(:put_application_authentication_method, params) req.send_request() end |
#put_application_grant(params = {}) ⇒ Struct
Creates a configuration for an application to use grants. Conceptually grants are authorization to request actions related to tokens. This configuration will be used when parties are requesting and receiving tokens during the trusted identity propagation process. For more information on the IAM Identity Center supported grant workflows, see [SAML 2.0 and OAuth 2.0].
A grant is created between your applications and Identity Center instance which enables an application to use specified mechanisms to obtain tokens. These tokens are used by your applications to gain access to Amazon Web Services resources on behalf of users. The following elements are within these exchanges:
-
Requester - The application requesting access to Amazon Web Services resources.
-
Subject - Typically the user that is requesting access to Amazon Web Services resources.
-
Grant - Conceptually, a grant is authorization to access Amazon Web Services resources. These grants authorize token generation for authenticating access to the requester and for the request to make requests on behalf of the subjects. There are four types of grants:
-
AuthorizationCode - Allows an application to request authorization through a series of user-agent redirects.
-
JWT bearer - Authorizes an application to exchange a JSON Web Token that came from an external identity provider. To learn more, see [RFC 6479].
-
**Refresh token** - Enables application to request new access tokens to replace expiring or expired access tokens.
-
**Exchange token** - A grant that requests tokens from the authorization server by providing a ‘subject’ token with access scope authorizing trusted identity propagation to this application. To learn more, see [RFC 8693].
-
-
**Authorization server** - IAM Identity Center requests tokens.
User credentials are never shared directly within these exchanges. Instead, applications use grants to request access tokens from IAM Identity Center. For more information, see [RFC 6479].
**Use cases**
-
Connecting to custom applications.
-
Configuring an Amazon Web Services service to make calls to another Amazon Web Services services using JWT tokens.
[1]: docs.aws.amazon.com/singlesignon/latest/userguide/customermanagedapps-saml2-oauth2.html [2]: datatracker.ietf.org/doc/html/rfc6749 [3]: datatracker.ietf.org/doc/html/rfc8693
3832 3833 3834 3835 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3832 def put_application_grant(params = {}, = {}) req = build_request(:put_application_grant, params) req.send_request() end |
#put_application_session_configuration(params = {}) ⇒ Struct
Updates the session configuration for an application in IAM Identity Center.
The session configuration determines how users can access an application. This includes whether user background sessions are enabled. User background sessions allow users to start a job on a supported Amazon Web Services managed application without having to remain signed in to an active session while the job runs.
3866 3867 3868 3869 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3866 def put_application_session_configuration(params = {}, = {}) req = build_request(:put_application_session_configuration, params) req.send_request() end |
#put_inline_policy_to_permission_set(params = {}) ⇒ Struct
Attaches an inline policy to a permission set.
<note markdown=“1”> If the permission set is already referenced by one or more account assignments, you will need to call ‘ ProvisionPermissionSet ` after this action to apply the corresponding IAM policy updates to all assigned accounts.
</note>
3907 3908 3909 3910 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3907 def (params = {}, = {}) req = build_request(:put_inline_policy_to_permission_set, params) req.send_request() end |
#put_permissions_boundary_to_permission_set(params = {}) ⇒ Struct
Attaches an Amazon Web Services managed or customer managed policy to the specified PermissionSet as a permissions boundary.
3945 3946 3947 3948 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 3945 def (params = {}, = {}) req = build_request(:put_permissions_boundary_to_permission_set, params) req.send_request() end |
#remove_region(params = {}) ⇒ Types::RemoveRegionResponse
Removes an additional Region from an IAM Identity Center instance. This operation initiates an asynchronous workflow to clean up IAM Identity Center resources in the specified additional Region. The Region status is set to REMOVING and the Region record is deleted when the workflow completes. The request must be made from the primary Region. The target Region cannot be the primary Region, and no other add or remove Region workflows can be in progress.
The following actions are related to ‘RemoveRegion`:
- AddRegion][1
- DescribeRegion][2
- ListRegions][3
[1]: docs.aws.amazon.com/singlesignon/latest/APIReference/API_AddRegion.html [2]: docs.aws.amazon.com/singlesignon/latest/APIReference/API_DescribeRegion.html [3]: docs.aws.amazon.com/singlesignon/latest/APIReference/API_ListRegions.html
4000 4001 4002 4003 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 4000 def remove_region(params = {}, = {}) req = build_request(:remove_region, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Associates a set of tags with a specified resource.
4039 4040 4041 4042 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 4039 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Disassociates a set of tags from a specified resource.
4073 4074 4075 4076 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 4073 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_application(params = {}) ⇒ Struct
Updates application properties.
4120 4121 4122 4123 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 4120 def update_application(params = {}, = {}) req = build_request(:update_application, params) req.send_request() end |
#update_instance(params = {}) ⇒ Struct
Update the details for the instance of IAM Identity Center that is owned by the Amazon Web Services account.
4160 4161 4162 4163 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 4160 def update_instance(params = {}, = {}) req = build_request(:update_instance, params) req.send_request() end |
#update_instance_access_control_attribute_configuration(params = {}) ⇒ Struct
Updates the IAM Identity Center identity store attributes that you can use with the IAM Identity Center instance for attributes-based access control (ABAC). When using an external identity provider as an identity source, you can pass attributes through the SAML assertion as an alternative to configuring attributes from the IAM Identity Center identity store. If a SAML assertion passes any of these attributes, IAM Identity Center replaces the attribute value with the value from the IAM Identity Center identity store. For more information about ABAC, see [Attribute-Based Access Control](/singlesignon/latest/userguide/abac.html) in the *IAM Identity Center User Guide*.
4206 4207 4208 4209 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 4206 def update_instance_access_control_attribute_configuration(params = {}, = {}) req = build_request(:update_instance_access_control_attribute_configuration, params) req.send_request() end |
#update_permission_set(params = {}) ⇒ Struct
Updates an existing permission set.
4250 4251 4252 4253 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 4250 def (params = {}, = {}) req = build_request(:update_permission_set, params) req.send_request() end |
#update_trusted_token_issuer(params = {}) ⇒ Struct
Updates the name of the trusted token issuer, or the path of a source attribute or destination attribute for a trusted token issuer configuration.
<note markdown=“1”> Updating this trusted token issuer configuration might cause users to lose access to any applications that are configured to use the trusted token issuer.
</note>
4298 4299 4300 4301 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 4298 def update_trusted_token_issuer(params = {}, = {}) req = build_request(:update_trusted_token_issuer, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4327 4328 4329 |
# File 'lib/aws-sdk-ssoadmin/client.rb', line 4327 def waiter_names [] end |