Class: Aws::SSOAdmin::Types::AccountAssignmentOperationStatus

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

The status of the creation or deletion operation of an assignment that a principal needs to access an account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_date ⇒ Time

The date that the permission set was created.

Returns:

  • (Time)


207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/aws-sdk-ssoadmin/types.rb', line 207

class AccountAssignmentOperationStatus < Struct.new(
  :status,
  :request_id,
  :failure_reason,
  :target_id,
  :target_type,
  :permission_set_arn,
  :principal_type,
  :principal_id,
  :created_date)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reason ⇒ String

The message that contains an error or exception in case of an operation failure.

Returns:

  • (String)


207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/aws-sdk-ssoadmin/types.rb', line 207

class AccountAssignmentOperationStatus < Struct.new(
  :status,
  :request_id,
  :failure_reason,
  :target_id,
  :target_type,
  :permission_set_arn,
  :principal_type,
  :principal_id,
  :created_date)
  SENSITIVE = []
  include Aws::Structure
end

#permission_set_arn ⇒ String

The ARN of the permission set. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

Returns:

  • (String)


207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/aws-sdk-ssoadmin/types.rb', line 207

class AccountAssignmentOperationStatus < Struct.new(
  :status,
  :request_id,
  :failure_reason,
  :target_id,
  :target_type,
  :permission_set_arn,
  :principal_type,
  :principal_id,
  :created_date)
  SENSITIVE = []
  include Aws::Structure
end

#principal_id ⇒ String

An identifier for an object in IAM Identity Center, such as a user or group. PrincipalIds are GUIDs (For example, f81d4fae-7dec-11d0-a765-00a0c91e6bf6). For more information about PrincipalIds in IAM Identity Center, see the IAM Identity Center Identity Store API Reference.

Returns:

  • (String)


207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/aws-sdk-ssoadmin/types.rb', line 207

class AccountAssignmentOperationStatus < Struct.new(
  :status,
  :request_id,
  :failure_reason,
  :target_id,
  :target_type,
  :permission_set_arn,
  :principal_type,
  :principal_id,
  :created_date)
  SENSITIVE = []
  include Aws::Structure
end

#principal_type ⇒ String

The entity type for which the assignment will be created.

Returns:

  • (String)


207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/aws-sdk-ssoadmin/types.rb', line 207

class AccountAssignmentOperationStatus < Struct.new(
  :status,
  :request_id,
  :failure_reason,
  :target_id,
  :target_type,
  :permission_set_arn,
  :principal_type,
  :principal_id,
  :created_date)
  SENSITIVE = []
  include Aws::Structure
end

#request_id ⇒ String

The identifier for tracking the request operation that is generated by the universally unique identifier (UUID) workflow.

Returns:

  • (String)


207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/aws-sdk-ssoadmin/types.rb', line 207

class AccountAssignmentOperationStatus < Struct.new(
  :status,
  :request_id,
  :failure_reason,
  :target_id,
  :target_type,
  :permission_set_arn,
  :principal_type,
  :principal_id,
  :created_date)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the permission set provisioning process.

Returns:

  • (String)


207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/aws-sdk-ssoadmin/types.rb', line 207

class AccountAssignmentOperationStatus < Struct.new(
  :status,
  :request_id,
  :failure_reason,
  :target_id,
  :target_type,
  :permission_set_arn,
  :principal_type,
  :principal_id,
  :created_date)
  SENSITIVE = []
  include Aws::Structure
end

#target_id ⇒ String

TargetID is an Amazon Web Services account identifier, (For example, 123456789012).

Returns:

  • (String)


207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/aws-sdk-ssoadmin/types.rb', line 207

class AccountAssignmentOperationStatus < Struct.new(
  :status,
  :request_id,
  :failure_reason,
  :target_id,
  :target_type,
  :permission_set_arn,
  :principal_type,
  :principal_id,
  :created_date)
  SENSITIVE = []
  include Aws::Structure
end

#target_type ⇒ String

The entity type for which the assignment will be created.

Returns:

  • (String)


207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/aws-sdk-ssoadmin/types.rb', line 207

class AccountAssignmentOperationStatus < Struct.new(
  :status,
  :request_id,
  :failure_reason,
  :target_id,
  :target_type,
  :permission_set_arn,
  :principal_type,
  :principal_id,
  :created_date)
  SENSITIVE = []
  include Aws::Structure
end