Class: Aws::SSOAdmin::Types::Application
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::Application
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
A structure that describes an application that uses IAM Identity Center for access management.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_account ⇒ String
The Amazon Web Services account ID number of the application.
-
#application_arn ⇒ String
The ARN of the application.
-
#application_provider_arn ⇒ String
The ARN of the application provider for this application.
-
#created_date ⇒ Time
The date and time when the application was originally created.
-
#created_from ⇒ String
The Amazon Web Services Region where the application was created in IAM Identity Center.
-
#description ⇒ String
The description of the application.
-
#identity_store_arn ⇒ String
The ARN of the identity store that is connected to the instance of IAM Identity Center.
-
#instance_arn ⇒ String
The ARN of the instance of IAM Identity Center that is configured with this application.
-
#name ⇒ String
The name of the application.
-
#portal_options ⇒ Types::PortalOptions
A structure that describes the options for the access portal associated with this application.
-
#status ⇒ String
The current status of the application in this instance of IAM Identity Center.
Instance Attribute Details
#application_account ⇒ String
The Amazon Web Services account ID number of the application.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 335 class Application < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#application_arn ⇒ String
The ARN of the application.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 335 class Application < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#application_provider_arn ⇒ String
The ARN of the application provider for this application.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 335 class Application < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ Time
The date and time when the application was originally created.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 335 class Application < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#created_from ⇒ String
The Amazon Web Services Region where the application was created in IAM Identity Center.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 335 class Application < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the application.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 335 class Application < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#identity_store_arn ⇒ String
The ARN of the identity store that is connected to the instance of IAM Identity Center.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 335 class Application < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#instance_arn ⇒ String
The ARN of the instance of IAM Identity Center that is configured with this application.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 335 class Application < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the application.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 335 class Application < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#portal_options ⇒ Types::PortalOptions
A structure that describes the options for the access portal associated with this application.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 335 class Application < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the application in this instance of IAM Identity Center.
335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 335 class Application < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |