Class: Aws::SSOAdmin::Types::AuthenticationMethodItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::AuthenticationMethodItem
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
A structure that describes an authentication method and its type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authentication_method ⇒ Types::AuthenticationMethod
A structure that describes an authentication method.
-
#authentication_method_type ⇒ String
The type of authentication that is used by this method.
Instance Attribute Details
#authentication_method ⇒ Types::AuthenticationMethod
A structure that describes an authentication method. The contents of this structure is determined by the ‘AuthenticationMethodType`.
558 559 560 561 562 563 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 558 class AuthenticationMethodItem < Struct.new( :authentication_method_type, :authentication_method) SENSITIVE = [] include Aws::Structure end |
#authentication_method_type ⇒ String
The type of authentication that is used by this method.
558 559 560 561 562 563 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 558 class AuthenticationMethodItem < Struct.new( :authentication_method_type, :authentication_method) SENSITIVE = [] include Aws::Structure end |