Class: Aws::SSOAdmin::Types::CreateApplicationResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_arnString

Specifies the ARN of the application.

Returns:

  • (String)


809
810
811
812
813
814
815
# File 'lib/aws-sdk-ssoadmin/types.rb', line 809

class CreateApplicationResponse < Struct.new(
  :application_arn,
  :instance_arn,
  :identity_store_arn)
  SENSITIVE = []
  include Aws::Structure
end

#identity_store_arnString

The ARN of the identity store that is connected to the instance of IAM Identity Center.

Returns:

  • (String)


809
810
811
812
813
814
815
# File 'lib/aws-sdk-ssoadmin/types.rb', line 809

class CreateApplicationResponse < Struct.new(
  :application_arn,
  :instance_arn,
  :identity_store_arn)
  SENSITIVE = []
  include Aws::Structure
end

#instance_arnString

The ARN of the instance of IAM Identity Center under which the operation will run. For more information about ARNs, see [Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces](/general/latest/gr/aws-arns-and-namespaces.html) in the *Amazon Web Services General Reference*.

Returns:

  • (String)


809
810
811
812
813
814
815
# File 'lib/aws-sdk-ssoadmin/types.rb', line 809

class CreateApplicationResponse < Struct.new(
  :application_arn,
  :instance_arn,
  :identity_store_arn)
  SENSITIVE = []
  include Aws::Structure
end