Class: Aws::SSOAdmin::Types::DescribeApplicationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::DescribeApplicationResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_account ⇒ String
The account ID.
-
#application_arn ⇒ String
Specifies the ARN of the application.
-
#application_provider_arn ⇒ String
The ARN of the application provider under which the operation will run.
-
#created_date ⇒ Time
The date the application was created.
-
#created_from ⇒ String
The Amazon Web Services Region where the application was created in IAM Identity Center.
-
#description ⇒ String
The description of the .
-
#identity_store_arn ⇒ String
The ARN of the identity store that is connected to the instance of IAM Identity Center.
-
#instance_arn ⇒ String
The ARN of the IAM Identity Center application under which the operation will run.
-
#name ⇒ String
The application name.
-
#portal_options ⇒ Types::PortalOptions
A structure that describes the options for the portal associated with an application.
-
#status ⇒ String
Specifies whether the application is enabled or disabled.
Instance Attribute Details
#application_account ⇒ String
The account ID.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1594 class DescribeApplicationResponse < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#application_arn ⇒ String
Specifies the ARN of the application.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1594 class DescribeApplicationResponse < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#application_provider_arn ⇒ String
The ARN of the application provider under which the operation will run.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1594 class DescribeApplicationResponse < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ Time
The date the application was created.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1594 class DescribeApplicationResponse < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#created_from ⇒ String
The Amazon Web Services Region where the application was created in IAM Identity Center.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1594 class DescribeApplicationResponse < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the .
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1594 class DescribeApplicationResponse < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#identity_store_arn ⇒ String
The ARN of the identity store that is connected to the instance of IAM Identity Center.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1594 class DescribeApplicationResponse < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#instance_arn ⇒ String
The ARN of the IAM Identity Center application under which the operation will run. For more information about ARNs, see [Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces](/general/latest/gr/aws-arns-and-namespaces.html) in the *Amazon Web Services General Reference*.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1594 class DescribeApplicationResponse < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The application name.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1594 class DescribeApplicationResponse < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#portal_options ⇒ Types::PortalOptions
A structure that describes the options for the portal associated with an application.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1594 class DescribeApplicationResponse < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Specifies whether the application is enabled or disabled.
1594 1595 1596 1597 1598 1599 1600 1601 1602 1603 1604 1605 1606 1607 1608 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1594 class DescribeApplicationResponse < Struct.new( :application_arn, :application_provider_arn, :name, :application_account, :instance_arn, :identity_store_arn, :status, :portal_options, :description, :created_date, :created_from) SENSITIVE = [] include Aws::Structure end |