Class: Aws::SSOAdmin::Types::DescribePermissionSetProvisioningStatusRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_arn ⇒ String

The ARN of the IAM Identity Center instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

Returns:

  • (String)


1760
1761
1762
1763
1764
1765
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1760

class DescribePermissionSetProvisioningStatusRequest < Struct.new(
  :instance_arn,
  :provision_permission_set_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#provision_permission_set_request_id ⇒ String

The identifier that is provided by the ProvisionPermissionSet call to retrieve the current status of the provisioning workflow.

Returns:

  • (String)


1760
1761
1762
1763
1764
1765
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1760

class DescribePermissionSetProvisioningStatusRequest < Struct.new(
  :instance_arn,
  :provision_permission_set_request_id)
  SENSITIVE = []
  include Aws::Structure
end