Class: Aws::SSOAdmin::Types::DescribePermissionSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_arn ⇒ String

The ARN of the IAM Identity Center instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

Returns:

  • (String)


1793
1794
1795
1796
1797
1798
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1793

class DescribePermissionSetRequest < Struct.new(
  :instance_arn,
  :permission_set_arn)
  SENSITIVE = []
  include Aws::Structure
end

#permission_set_arn ⇒ String

The ARN of the permission set.

Returns:

  • (String)


1793
1794
1795
1796
1797
1798
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1793

class DescribePermissionSetRequest < Struct.new(
  :instance_arn,
  :permission_set_arn)
  SENSITIVE = []
  include Aws::Structure
end