Class: Aws::SSOAdmin::Types::DetachCustomerManagedPolicyReferenceFromPermissionSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::DetachCustomerManagedPolicyReferenceFromPermissionSetRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#customer_managed_policy_reference ⇒ Types::CustomerManagedPolicyReference
Specifies the name and path of a customer managed policy.
-
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance under which the operation will be executed.
-
#permission_set_arn ⇒ String
The ARN of the
PermissionSet.
Instance Attribute Details
#customer_managed_policy_reference ⇒ Types::CustomerManagedPolicyReference
Specifies the name and path of a customer managed policy. You must have an IAM policy that matches the name and path in each Amazon Web Services account where you want to deploy your permission set.
1928 1929 1930 1931 1932 1933 1934 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1928 class DetachCustomerManagedPolicyReferenceFromPermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn, :customer_managed_policy_reference) SENSITIVE = [] include Aws::Structure end |
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance under which the operation will be executed.
1928 1929 1930 1931 1932 1933 1934 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1928 class DetachCustomerManagedPolicyReferenceFromPermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn, :customer_managed_policy_reference) SENSITIVE = [] include Aws::Structure end |
#permission_set_arn ⇒ String
The ARN of the PermissionSet.
1928 1929 1930 1931 1932 1933 1934 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1928 class DetachCustomerManagedPolicyReferenceFromPermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn, :customer_managed_policy_reference) SENSITIVE = [] include Aws::Structure end |