Class: Aws::SSOAdmin::Types::DetachManagedPolicyFromPermissionSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_arn ⇒ String

The ARN of the IAM Identity Center instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

Returns:

  • (String)


1960
1961
1962
1963
1964
1965
1966
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1960

class DetachManagedPolicyFromPermissionSetRequest < Struct.new(
  :instance_arn,
  :permission_set_arn,
  :managed_policy_arn)
  SENSITIVE = []
  include Aws::Structure
end

#managed_policy_arn ⇒ String

The Amazon Web Services managed policy ARN to be detached from a permission set.

Returns:

  • (String)


1960
1961
1962
1963
1964
1965
1966
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1960

class DetachManagedPolicyFromPermissionSetRequest < Struct.new(
  :instance_arn,
  :permission_set_arn,
  :managed_policy_arn)
  SENSITIVE = []
  include Aws::Structure
end

#permission_set_arn ⇒ String

The ARN of the PermissionSet from which the policy should be detached.

Returns:

  • (String)


1960
1961
1962
1963
1964
1965
1966
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1960

class DetachManagedPolicyFromPermissionSetRequest < Struct.new(
  :instance_arn,
  :permission_set_arn,
  :managed_policy_arn)
  SENSITIVE = []
  include Aws::Structure
end