Class: Aws::SSOAdmin::Types::DisplayData

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

A structure that describes how the portal represents an application provider.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#description ⇒ String

The description of the application provider that appears in the portal.

Returns:

  • (String)


1991
1992
1993
1994
1995
1996
1997
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1991

class DisplayData < Struct.new(
  :display_name,
  :icon_url,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#display_name ⇒ String

The name of the application provider that appears in the portal.

Returns:

  • (String)


1991
1992
1993
1994
1995
1996
1997
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1991

class DisplayData < Struct.new(
  :display_name,
  :icon_url,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#icon_url ⇒ String

A URL that points to an icon that represents the application provider.

Returns:

  • (String)


1991
1992
1993
1994
1995
1996
1997
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1991

class DisplayData < Struct.new(
  :display_name,
  :icon_url,
  :description)
  SENSITIVE = []
  include Aws::Structure
end