Class: Aws::SSOAdmin::Types::InstanceMetadata

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Provides information about the IAM Identity Center instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_date ⇒ Time

The date and time that the Identity Center instance was created.

Returns:

  • (Time)


2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2434

class InstanceMetadata < Struct.new(
  :instance_arn,
  :identity_store_id,
  :identity_store_arn,
  :owner_account_id,
  :name,
  :created_date,
  :status,
  :status_reason,
  :primary_region,
  :regions)
  SENSITIVE = []
  include Aws::Structure
end

#identity_store_arn ⇒ String

The ARN of the identity store that is connected to the Identity Center instance.

Returns:

  • (String)


2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2434

class InstanceMetadata < Struct.new(
  :instance_arn,
  :identity_store_id,
  :identity_store_arn,
  :owner_account_id,
  :name,
  :created_date,
  :status,
  :status_reason,
  :primary_region,
  :regions)
  SENSITIVE = []
  include Aws::Structure
end

#identity_store_id ⇒ String

The identifier of the identity store that is connected to the Identity Center instance.

Returns:

  • (String)


2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2434

class InstanceMetadata < Struct.new(
  :instance_arn,
  :identity_store_id,
  :identity_store_arn,
  :owner_account_id,
  :name,
  :created_date,
  :status,
  :status_reason,
  :primary_region,
  :regions)
  SENSITIVE = []
  include Aws::Structure
end

#instance_arn ⇒ String

The ARN of the Identity Center instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

Returns:

  • (String)


2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2434

class InstanceMetadata < Struct.new(
  :instance_arn,
  :identity_store_id,
  :identity_store_arn,
  :owner_account_id,
  :name,
  :created_date,
  :status,
  :status_reason,
  :primary_region,
  :regions)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the Identity Center instance.

Returns:

  • (String)


2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2434

class InstanceMetadata < Struct.new(
  :instance_arn,
  :identity_store_id,
  :identity_store_arn,
  :owner_account_id,
  :name,
  :created_date,
  :status,
  :status_reason,
  :primary_region,
  :regions)
  SENSITIVE = []
  include Aws::Structure
end

#owner_account_id ⇒ String

The Amazon Web Services account ID number of the owner of the Identity Center instance.

Returns:

  • (String)


2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2434

class InstanceMetadata < Struct.new(
  :instance_arn,
  :identity_store_id,
  :identity_store_arn,
  :owner_account_id,
  :name,
  :created_date,
  :status,
  :status_reason,
  :primary_region,
  :regions)
  SENSITIVE = []
  include Aws::Structure
end

#primary_region ⇒ String

The primary Region where the IAM Identity Center instance was originally enabled. The primary Region cannot be removed.

Returns:

  • (String)


2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2434

class InstanceMetadata < Struct.new(
  :instance_arn,
  :identity_store_id,
  :identity_store_arn,
  :owner_account_id,
  :name,
  :created_date,
  :status,
  :status_reason,
  :primary_region,
  :regions)
  SENSITIVE = []
  include Aws::Structure
end

#regions ⇒ Array<Types::RegionMetadata>

The list of Regions enabled in the IAM Identity Center instance, including Regions with ACTIVE, ADDING, or REMOVING status.

Returns:



2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2434

class InstanceMetadata < Struct.new(
  :instance_arn,
  :identity_store_id,
  :identity_store_arn,
  :owner_account_id,
  :name,
  :created_date,
  :status,
  :status_reason,
  :primary_region,
  :regions)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of this Identity Center instance.

Returns:

  • (String)


2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2434

class InstanceMetadata < Struct.new(
  :instance_arn,
  :identity_store_id,
  :identity_store_arn,
  :owner_account_id,
  :name,
  :created_date,
  :status,
  :status_reason,
  :primary_region,
  :regions)
  SENSITIVE = []
  include Aws::Structure
end

#status_reason ⇒ String

Provides additional context about the current status of the IAM Identity Center instance. This field is particularly useful when an instance is in a non-ACTIVE state, such as CREATE_FAILED. When an instance creation fails, this field contains information about the cause, which may include issues with KMS key configuration or insufficient permissions.

Returns:

  • (String)


2434
2435
2436
2437
2438
2439
2440
2441
2442
2443
2444
2445
2446
2447
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2434

class InstanceMetadata < Struct.new(
  :instance_arn,
  :identity_store_id,
  :identity_store_arn,
  :owner_account_id,
  :name,
  :created_date,
  :status,
  :status_reason,
  :primary_region,
  :regions)
  SENSITIVE = []
  include Aws::Structure
end