Class: Aws::SSOAdmin::Types::InternalServerException

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

The request processing has failed because of an unknown error, exception, or failure with an internal server.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


2415
2416
2417
2418
2419
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2415

class InternalServerException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end