Class: Aws::SSOAdmin::Types::ListApplicationAuthenticationMethodsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_arnString

Specifies the ARN of the application with the authentication methods you want to list.

Returns:

  • (String)


2942
2943
2944
2945
2946
2947
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2942

class ListApplicationAuthenticationMethodsRequest < Struct.new(
  :application_arn,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Specifies that you want to receive the next page of results. Valid only if you received a NextToken response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call’s NextToken response to request the next page of results.

Returns:

  • (String)


2942
2943
2944
2945
2946
2947
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2942

class ListApplicationAuthenticationMethodsRequest < Struct.new(
  :application_arn,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end