Class: Aws::SSOAdmin::Types::ListApplicationAuthenticationMethodsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::ListApplicationAuthenticationMethodsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authentication_methods ⇒ Array<Types::AuthenticationMethodItem>
An array list of authentication methods for the specified application.
-
#next_token ⇒ String
If present, this value indicates that more output is available than is included in the current response.
Instance Attribute Details
#authentication_methods ⇒ Array<Types::AuthenticationMethodItem>
An array list of authentication methods for the specified application.
2965 2966 2967 2968 2969 2970 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2965 class ListApplicationAuthenticationMethodsResponse < Struct.new( :authentication_methods, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If present, this value indicates that more output is available than is included in the current response. Use this value in the NextToken request parameter in a subsequent call to the operation to get the next part of the output. You should repeat this until the NextToken response element comes back as null. This indicates that this is the last page of results.
2965 2966 2967 2968 2969 2970 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2965 class ListApplicationAuthenticationMethodsResponse < Struct.new( :authentication_methods, :next_token) SENSITIVE = [] include Aws::Structure end |