Class: Aws::SSOAdmin::Types::ListCustomerManagedPolicyReferencesInPermissionSetResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#customer_managed_policy_references ⇒ Array<Types::CustomerManagedPolicyReference>

Specifies the names and paths of the customer managed policies that you have attached to your permission set.



3262
3263
3264
3265
3266
3267
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3262

class ListCustomerManagedPolicyReferencesInPermissionSetResponse < Struct.new(
  :customer_managed_policy_references,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The pagination token for the list API. Initially the value is null. Use the output of previous API calls to make subsequent calls.

Returns:

  • (String)


3262
3263
3264
3265
3266
3267
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3262

class ListCustomerManagedPolicyReferencesInPermissionSetResponse < Struct.new(
  :customer_managed_policy_references,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end