Class: Aws::SSOAdmin::Types::ListManagedPoliciesInPermissionSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#instance_arn ⇒ String

The ARN of the IAM Identity Center instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

Returns:

  • (String)


3329
3330
3331
3332
3333
3334
3335
3336
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3329

class ListManagedPoliciesInPermissionSetRequest < Struct.new(
  :instance_arn,
  :permission_set_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to display for the PermissionSet.

Returns:

  • (Integer)


3329
3330
3331
3332
3333
3334
3335
3336
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3329

class ListManagedPoliciesInPermissionSetRequest < Struct.new(
  :instance_arn,
  :permission_set_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The pagination token for the list API. Initially the value is null. Use the output of previous API calls to make subsequent calls.

Returns:

  • (String)


3329
3330
3331
3332
3333
3334
3335
3336
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3329

class ListManagedPoliciesInPermissionSetRequest < Struct.new(
  :instance_arn,
  :permission_set_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#permission_set_arn ⇒ String

The ARN of the PermissionSet whose managed policies will be listed.

Returns:

  • (String)


3329
3330
3331
3332
3333
3334
3335
3336
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3329

class ListManagedPoliciesInPermissionSetRequest < Struct.new(
  :instance_arn,
  :permission_set_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end