Class: Aws::SSOAdmin::Types::ListPermissionSetProvisioningStatusRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filter ⇒ Types::OperationStatusFilter

Filters results based on the passed attribute value.



3379
3380
3381
3382
3383
3384
3385
3386
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3379

class ListPermissionSetProvisioningStatusRequest < Struct.new(
  :instance_arn,
  :max_results,
  :next_token,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#instance_arn ⇒ String

The ARN of the IAM Identity Center instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

Returns:

  • (String)


3379
3380
3381
3382
3383
3384
3385
3386
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3379

class ListPermissionSetProvisioningStatusRequest < Struct.new(
  :instance_arn,
  :max_results,
  :next_token,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of results to display for the assignment.

Returns:

  • (Integer)


3379
3380
3381
3382
3383
3384
3385
3386
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3379

class ListPermissionSetProvisioningStatusRequest < Struct.new(
  :instance_arn,
  :max_results,
  :next_token,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The pagination token for the list API. Initially the value is null. Use the output of previous API calls to make subsequent calls.

Returns:

  • (String)


3379
3380
3381
3382
3383
3384
3385
3386
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3379

class ListPermissionSetProvisioningStatusRequest < Struct.new(
  :instance_arn,
  :max_results,
  :next_token,
  :filter)
  SENSITIVE = []
  include Aws::Structure
end