Class: Aws::SSOAdmin::Types::ListPermissionSetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::ListPermissionSetsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance under which the operation will be executed.
-
#max_results ⇒ Integer
The maximum number of results to display for the assignment.
-
#next_token ⇒ String
The pagination token for the list API.
Instance Attribute Details
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
3481 3482 3483 3484 3485 3486 3487 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3481 class ListPermissionSetsRequest < Struct.new( :instance_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to display for the assignment.
3481 3482 3483 3484 3485 3486 3487 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3481 class ListPermissionSetsRequest < Struct.new( :instance_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token for the list API. Initially the value is null. Use the output of previous API calls to make subsequent calls.
3481 3482 3483 3484 3485 3486 3487 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3481 class ListPermissionSetsRequest < Struct.new( :instance_arn, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |