Class: Aws::SSOAdmin::Types::ListRegionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The pagination token to be used in subsequent calls. If the value is null, then there are no more entries.

Returns:

  • (String)


3474
3475
3476
3477
3478
3479
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3474

class ListRegionsResponse < Struct.new(
  :regions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#regionsArray<Types::RegionMetadata>

The list of Regions enabled in the IAM Identity Center instance, including Regions with ACTIVE, ADDING, or REMOVING status.

Returns:



3474
3475
3476
3477
3478
3479
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3474

class ListRegionsResponse < Struct.new(
  :regions,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end