Class: Aws::SSOAdmin::Types::ListTrustedTokenIssuersRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::ListTrustedTokenIssuersRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_arn ⇒ String
Specifies the ARN of the instance of IAM Identity Center with the trusted token issuer configurations that you want to list.
-
#max_results ⇒ Integer
Specifies the total number of results that you want included in each response.
-
#next_token ⇒ String
Specifies that you want to receive the next page of results.
Instance Attribute Details
#instance_arn ⇒ String
Specifies the ARN of the instance of IAM Identity Center with the trusted token issuer configurations that you want to list.
3553 3554 3555 3556 3557 3558 3559 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3553 class ListTrustedTokenIssuersRequest < Struct.new( :instance_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Specifies the total number of results that you want included in each response. If additional items exist beyond the number you specify, the NextToken response element is returned with a value (not null). Include the specified value as the NextToken request parameter in the next call to the operation to get the next set of results. Note that the service might return fewer results than the maximum even when there are more results available. You should check NextToken after every operation to ensure that you receive all of the results.
3553 3554 3555 3556 3557 3558 3559 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3553 class ListTrustedTokenIssuersRequest < Struct.new( :instance_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies that you want to receive the next page of results. Valid only if you received a NextToken response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call’s NextToken response to request the next page of results.
3553 3554 3555 3556 3557 3558 3559 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3553 class ListTrustedTokenIssuersRequest < Struct.new( :instance_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |