Class: Aws::SSOAdmin::Types::ListTrustedTokenIssuersResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_token ⇒ String

If present, this value indicates that more output is available than is included in the current response. Use this value in the NextToken request parameter in a subsequent call to the operation to get the next part of the output. You should repeat this until the NextToken response element comes back as null. This indicates that this is the last page of results.

Returns:

  • (String)


3645
3646
3647
3648
3649
3650
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3645

class ListTrustedTokenIssuersResponse < Struct.new(
  :trusted_token_issuers,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#trusted_token_issuers ⇒ Array<Types::TrustedTokenIssuerMetadata>

An array list of the trusted token issuer configurations.



3645
3646
3647
3648
3649
3650
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3645

class ListTrustedTokenIssuersResponse < Struct.new(
  :trusted_token_issuers,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end