Class: Aws::SSOAdmin::Types::OidcJwtUpdateConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::OidcJwtUpdateConfiguration
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
A structure that describes updated configuration settings for a trusted token issuer that supports OpenID Connect (OIDC) and JSON Web Tokens (JWTs).
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#claim_attribute_path ⇒ String
The path of the source attribute in the JWT from the trusted token issuer.
-
#identity_store_attribute_path ⇒ String
The path of the destination attribute in a JWT from IAM Identity Center.
-
#jwks_retrieval_option ⇒ String
The method that the trusted token issuer can use to retrieve the JSON Web Key Set used to verify a JWT.
Instance Attribute Details
#claim_attribute_path ⇒ String
The path of the source attribute in the JWT from the trusted token
issuer. The attribute mapped by this JMESPath expression is compared
against the attribute mapped by IdentityStoreAttributePath when a
trusted token issuer token is exchanged for an IAM Identity Center
token.
3694 3695 3696 3697 3698 3699 3700 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3694 class OidcJwtUpdateConfiguration < Struct.new( :claim_attribute_path, :identity_store_attribute_path, :jwks_retrieval_option) SENSITIVE = [] include Aws::Structure end |
#identity_store_attribute_path ⇒ String
The path of the destination attribute in a JWT from IAM Identity
Center. The attribute mapped by this JMESPath expression is compared
against the attribute mapped by ClaimAttributePath when a trusted
token issuer token is exchanged for an IAM Identity Center token.
3694 3695 3696 3697 3698 3699 3700 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3694 class OidcJwtUpdateConfiguration < Struct.new( :claim_attribute_path, :identity_store_attribute_path, :jwks_retrieval_option) SENSITIVE = [] include Aws::Structure end |
#jwks_retrieval_option ⇒ String
The method that the trusted token issuer can use to retrieve the JSON Web Key Set used to verify a JWT.
3694 3695 3696 3697 3698 3699 3700 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3694 class OidcJwtUpdateConfiguration < Struct.new( :claim_attribute_path, :identity_store_attribute_path, :jwks_retrieval_option) SENSITIVE = [] include Aws::Structure end |