Class: Aws::SSOAdmin::Types::PortalOptions

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

A structure that describes the options for the access portal associated with an application.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#sign_in_options ⇒ Types::SignInOptions

A structure that describes the sign-in options for the access portal.



3909
3910
3911
3912
3913
3914
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3909

class PortalOptions < Struct.new(
  :sign_in_options,
  :visibility)
  SENSITIVE = []
  include Aws::Structure
end

#visibility ⇒ String

Indicates whether this application is visible in the access portal.

Returns:

  • (String)


3909
3910
3911
3912
3913
3914
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3909

class PortalOptions < Struct.new(
  :sign_in_options,
  :visibility)
  SENSITIVE = []
  include Aws::Structure
end