Class: Aws::SSOAdmin::Types::PutApplicationAuthenticationMethodRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_arn ⇒ String

Specifies the ARN of the application with the authentication method to add or update.

Returns:

  • (String)


4034
4035
4036
4037
4038
4039
4040
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4034

class PutApplicationAuthenticationMethodRequest < Struct.new(
  :application_arn,
  :authentication_method_type,
  :authentication_method)
  SENSITIVE = []
  include Aws::Structure
end

#authentication_method ⇒ Types::AuthenticationMethod

Specifies a structure that describes the authentication method to add or update. The structure type you provide is determined by the AuthenticationMethodType parameter.



4034
4035
4036
4037
4038
4039
4040
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4034

class PutApplicationAuthenticationMethodRequest < Struct.new(
  :application_arn,
  :authentication_method_type,
  :authentication_method)
  SENSITIVE = []
  include Aws::Structure
end

#authentication_method_type ⇒ String

Specifies the type of the authentication method that you want to add or update.

Returns:

  • (String)


4034
4035
4036
4037
4038
4039
4040
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4034

class PutApplicationAuthenticationMethodRequest < Struct.new(
  :application_arn,
  :authentication_method_type,
  :authentication_method)
  SENSITIVE = []
  include Aws::Structure
end