Class: Aws::SSOAdmin::Types::RegionMetadata

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Contains information about an enabled Region of an IAM Identity Center instance, including the Region name, status, date added, and whether it is the primary Region.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#added_date ⇒ Time

The timestamp when the Region was added to the IAM Identity Center instance. For the primary Region, this is the instance creation time.

Returns:

  • (Time)


4186
4187
4188
4189
4190
4191
4192
4193
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4186

class RegionMetadata < Struct.new(
  :region_name,
  :status,
  :added_date,
  :is_primary_region)
  SENSITIVE = []
  include Aws::Structure
end

#is_primary_region ⇒ Boolean

Indicates whether this is the primary Region where the IAM Identity Center instance was originally enabled. The primary Region cannot be removed.

Returns:

  • (Boolean)


4186
4187
4188
4189
4190
4191
4192
4193
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4186

class RegionMetadata < Struct.new(
  :region_name,
  :status,
  :added_date,
  :is_primary_region)
  SENSITIVE = []
  include Aws::Structure
end

#region_name ⇒ String

The Amazon Web Services Region name.

Returns:

  • (String)


4186
4187
4188
4189
4190
4191
4192
4193
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4186

class RegionMetadata < Struct.new(
  :region_name,
  :status,
  :added_date,
  :is_primary_region)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of the Region. Valid values are ACTIVE (Region is operational), ADDING (Region extension workflow is in progress), or REMOVING (Region removal workflow is in progress).

Returns:

  • (String)


4186
4187
4188
4189
4190
4191
4192
4193
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4186

class RegionMetadata < Struct.new(
  :region_name,
  :status,
  :added_date,
  :is_primary_region)
  SENSITIVE = []
  include Aws::Structure
end