Class: Aws::SSOAdmin::Types::UpdateApplicationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_arn ⇒ String

Specifies the ARN of the application. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

Returns:

  • (String)


4581
4582
4583
4584
4585
4586
4587
4588
4589
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4581

class UpdateApplicationRequest < Struct.new(
  :application_arn,
  :name,
  :description,
  :status,
  :portal_options)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the .

Returns:

  • (String)


4581
4582
4583
4584
4585
4586
4587
4588
4589
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4581

class UpdateApplicationRequest < Struct.new(
  :application_arn,
  :name,
  :description,
  :status,
  :portal_options)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

Specifies the updated name for the application.

Returns:

  • (String)


4581
4582
4583
4584
4585
4586
4587
4588
4589
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4581

class UpdateApplicationRequest < Struct.new(
  :application_arn,
  :name,
  :description,
  :status,
  :portal_options)
  SENSITIVE = []
  include Aws::Structure
end

#portal_options ⇒ Types::UpdateApplicationPortalOptions

A structure that describes the options for the portal associated with an application.



4581
4582
4583
4584
4585
4586
4587
4588
4589
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4581

class UpdateApplicationRequest < Struct.new(
  :application_arn,
  :name,
  :description,
  :status,
  :portal_options)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

Specifies whether the application is enabled or disabled.

Returns:

  • (String)


4581
4582
4583
4584
4585
4586
4587
4588
4589
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4581

class UpdateApplicationRequest < Struct.new(
  :application_arn,
  :name,
  :description,
  :status,
  :portal_options)
  SENSITIVE = []
  include Aws::Structure
end