Class: Aws::SSOAdmin::Types::UpdateInstanceRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encryption_configurationTypes::EncryptionConfiguration

Specifies the encryption configuration for your IAM Identity Center instance. You can use this to configure customer managed KMS keys or Amazon Web Services owned KMS keys for encrypting your instance data.



4626
4627
4628
4629
4630
4631
4632
4633
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4626

class UpdateInstanceRequest < Struct.new(
  :name,
  :instance_arn,
  :encryption_configuration,
  :permission_sets_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#instance_arnString

The ARN of the instance of IAM Identity Center under which the operation will run. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

Returns:

  • (String)


4626
4627
4628
4629
4630
4631
4632
4633
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4626

class UpdateInstanceRequest < Struct.new(
  :name,
  :instance_arn,
  :encryption_configuration,
  :permission_sets_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Updates the instance name.

Returns:

  • (String)


4626
4627
4628
4629
4630
4631
4632
4633
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4626

class UpdateInstanceRequest < Struct.new(
  :name,
  :instance_arn,
  :encryption_configuration,
  :permission_sets_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#permission_sets_enabledBoolean

Enables permission sets for this Identity Center instance. The only accepted value is true . After permission sets are enabled, they cannot be disabled.

You can't set EncryptionConfiguration and PermissionSetsEnabled in the same request. To configure both, make two separate UpdateInstance calls. These calls can be made in parallel.

Returns:

  • (Boolean)


4626
4627
4628
4629
4630
4631
4632
4633
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4626

class UpdateInstanceRequest < Struct.new(
  :name,
  :instance_arn,
  :encryption_configuration,
  :permission_sets_enabled)
  SENSITIVE = []
  include Aws::Structure
end