Class: Aws::SSOAdmin::Types::UpdatePermissionSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::UpdatePermissionSetRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the PermissionSet.
-
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance under which the operation will be executed.
-
#permission_set_arn ⇒ String
The ARN of the permission set.
-
#relay_state ⇒ String
Used to redirect users within the application during the federation authentication process.
-
#session_duration ⇒ String
The length of time that the application user sessions are valid for in the ISO-8601 standard.
Instance Attribute Details
#description ⇒ String
The description of the PermissionSet.
4691 4692 4693 4694 4695 4696 4697 4698 4699 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4691 class UpdatePermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn, :description, :session_duration, :relay_state) SENSITIVE = [] include Aws::Structure end |
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
4691 4692 4693 4694 4695 4696 4697 4698 4699 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4691 class UpdatePermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn, :description, :session_duration, :relay_state) SENSITIVE = [] include Aws::Structure end |
#permission_set_arn ⇒ String
The ARN of the permission set.
4691 4692 4693 4694 4695 4696 4697 4698 4699 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4691 class UpdatePermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn, :description, :session_duration, :relay_state) SENSITIVE = [] include Aws::Structure end |
#relay_state ⇒ String
Used to redirect users within the application during the federation authentication process.
4691 4692 4693 4694 4695 4696 4697 4698 4699 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4691 class UpdatePermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn, :description, :session_duration, :relay_state) SENSITIVE = [] include Aws::Structure end |
#session_duration ⇒ String
The length of time that the application user sessions are valid for in the ISO-8601 standard.
4691 4692 4693 4694 4695 4696 4697 4698 4699 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4691 class UpdatePermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn, :description, :session_duration, :relay_state) SENSITIVE = [] include Aws::Structure end |