Class: Aws::SSOAdmin::Types::UpdateTrustedTokenIssuerRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::UpdateTrustedTokenIssuerRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
Specifies the updated name to be applied to the trusted token issuer configuration.
-
#trusted_token_issuer_arn ⇒ String
Specifies the ARN of the trusted token issuer configuration that you want to update.
-
#trusted_token_issuer_configuration ⇒ Types::TrustedTokenIssuerUpdateConfiguration
Specifies a structure with settings to apply to the specified trusted token issuer.
Instance Attribute Details
#name ⇒ String
Specifies the updated name to be applied to the trusted token issuer configuration.
4724 4725 4726 4727 4728 4729 4730 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4724 class UpdateTrustedTokenIssuerRequest < Struct.new( :trusted_token_issuer_arn, :name, :trusted_token_issuer_configuration) SENSITIVE = [] include Aws::Structure end |
#trusted_token_issuer_arn ⇒ String
Specifies the ARN of the trusted token issuer configuration that you want to update.
4724 4725 4726 4727 4728 4729 4730 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4724 class UpdateTrustedTokenIssuerRequest < Struct.new( :trusted_token_issuer_arn, :name, :trusted_token_issuer_configuration) SENSITIVE = [] include Aws::Structure end |
#trusted_token_issuer_configuration ⇒ Types::TrustedTokenIssuerUpdateConfiguration
Specifies a structure with settings to apply to the specified trusted token issuer. The settings that you can provide are determined by the type of the trusted token issuer that you are updating.
4724 4725 4726 4727 4728 4729 4730 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4724 class UpdateTrustedTokenIssuerRequest < Struct.new( :trusted_token_issuer_arn, :name, :trusted_token_issuer_configuration) SENSITIVE = [] include Aws::Structure end |