Class: Aws::SSOAdmin::Types::CreateApplicationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::CreateApplicationResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_arn ⇒ String
Specifies the ARN of the application.
-
#identity_store_arn ⇒ String
The ARN of the identity store that is connected to the instance of IAM Identity Center.
-
#instance_arn ⇒ String
The ARN of the instance of IAM Identity Center under which the operation will run.
Instance Attribute Details
#application_arn ⇒ String
Specifies the ARN of the application.
809 810 811 812 813 814 815 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 809 class CreateApplicationResponse < Struct.new( :application_arn, :instance_arn, :identity_store_arn) SENSITIVE = [] include Aws::Structure end |
#identity_store_arn ⇒ String
The ARN of the identity store that is connected to the instance of IAM Identity Center.
809 810 811 812 813 814 815 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 809 class CreateApplicationResponse < Struct.new( :application_arn, :instance_arn, :identity_store_arn) SENSITIVE = [] include Aws::Structure end |
#instance_arn ⇒ String
The ARN of the instance of IAM Identity Center under which the operation will run. For more information about ARNs, see [Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces](/general/latest/gr/aws-arns-and-namespaces.html) in the *Amazon Web Services General Reference*.
809 810 811 812 813 814 815 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 809 class CreateApplicationResponse < Struct.new( :application_arn, :instance_arn, :identity_store_arn) SENSITIVE = [] include Aws::Structure end |