Class: Aws::SSOAdmin::Types::DescribeInstanceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::DescribeInstanceResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_date ⇒ Time
The date the instance was created.
-
#encryption_configuration_details ⇒ Types::EncryptionConfigurationDetails
Contains the encryption configuration for your IAM Identity Center instance, including the encryption status, KMS key type, and KMS key ARN.
-
#identity_store_id ⇒ String
The identifier of the identity store that is connected to the instance of IAM Identity Center.
-
#instance_arn ⇒ String
The ARN of the instance of IAM Identity Center under which the operation will run.
-
#name ⇒ String
Specifies the instance name.
-
#owner_account_id ⇒ String
The identifier of the Amazon Web Services account for which the instance was created.
-
#status ⇒ String
The status of the instance.
-
#status_reason ⇒ String
Provides additional context about the current status of the IAM Identity Center instance.
Instance Attribute Details
#created_date ⇒ Time
The date the instance was created.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1708 class DescribeInstanceResponse < Struct.new( :instance_arn, :identity_store_id, :owner_account_id, :name, :created_date, :status, :status_reason, :encryption_configuration_details) SENSITIVE = [] include Aws::Structure end |
#encryption_configuration_details ⇒ Types::EncryptionConfigurationDetails
Contains the encryption configuration for your IAM Identity Center instance, including the encryption status, KMS key type, and KMS key ARN.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1708 class DescribeInstanceResponse < Struct.new( :instance_arn, :identity_store_id, :owner_account_id, :name, :created_date, :status, :status_reason, :encryption_configuration_details) SENSITIVE = [] include Aws::Structure end |
#identity_store_id ⇒ String
The identifier of the identity store that is connected to the instance of IAM Identity Center.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1708 class DescribeInstanceResponse < Struct.new( :instance_arn, :identity_store_id, :owner_account_id, :name, :created_date, :status, :status_reason, :encryption_configuration_details) SENSITIVE = [] include Aws::Structure end |
#instance_arn ⇒ String
The ARN of the instance of IAM Identity Center under which the operation will run. For more information about ARNs, see [Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces](/general/latest/gr/aws-arns-and-namespaces.html) in the *Amazon Web Services General Reference*.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1708 class DescribeInstanceResponse < Struct.new( :instance_arn, :identity_store_id, :owner_account_id, :name, :created_date, :status, :status_reason, :encryption_configuration_details) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Specifies the instance name.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1708 class DescribeInstanceResponse < Struct.new( :instance_arn, :identity_store_id, :owner_account_id, :name, :created_date, :status, :status_reason, :encryption_configuration_details) SENSITIVE = [] include Aws::Structure end |
#owner_account_id ⇒ String
The identifier of the Amazon Web Services account for which the instance was created.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1708 class DescribeInstanceResponse < Struct.new( :instance_arn, :identity_store_id, :owner_account_id, :name, :created_date, :status, :status_reason, :encryption_configuration_details) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the instance.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1708 class DescribeInstanceResponse < Struct.new( :instance_arn, :identity_store_id, :owner_account_id, :name, :created_date, :status, :status_reason, :encryption_configuration_details) SENSITIVE = [] include Aws::Structure end |
#status_reason ⇒ String
Provides additional context about the current status of the IAM Identity Center instance. This field is particularly useful when an instance is in a non-ACTIVE state, such as CREATE_FAILED. When an instance fails to create or update, this field contains information about the cause, which may include issues with KMS key configuration, permission problems with the specified KMS key, or service-related errors.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1708 class DescribeInstanceResponse < Struct.new( :instance_arn, :identity_store_id, :owner_account_id, :name, :created_date, :status, :status_reason, :encryption_configuration_details) SENSITIVE = [] include Aws::Structure end |