Class: Aws::SSOAdmin::Types::DescribePermissionSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::DescribePermissionSetRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance under which the operation will be executed.
-
#permission_set_arn ⇒ String
The ARN of the permission set.
Instance Attribute Details
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
1793 1794 1795 1796 1797 1798 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1793 class DescribePermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn) SENSITIVE = [] include Aws::Structure end |
#permission_set_arn ⇒ String
The ARN of the permission set.
1793 1794 1795 1796 1797 1798 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1793 class DescribePermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn) SENSITIVE = [] include Aws::Structure end |