Class: Aws::SSOAdmin::Types::DescribeRegionResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#added_dateTime

The timestamp when the Region was added to the IAM Identity Center instance. For the primary Region, this is the IAM Identity Center instance creation time.

Returns:

  • (Time)


1843
1844
1845
1846
1847
1848
1849
1850
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1843

class DescribeRegionResponse < Struct.new(
  :region_name,
  :status,
  :added_date,
  :is_primary_region)
  SENSITIVE = []
  include Aws::Structure
end

#is_primary_regionBoolean

Indicates whether this is the primary Region where the IAM Identity Center instance was originally enabled. For more information on the difference between the primary Region and additional Regions, see IAM Identity Center User Guide

Returns:

  • (Boolean)


1843
1844
1845
1846
1847
1848
1849
1850
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1843

class DescribeRegionResponse < Struct.new(
  :region_name,
  :status,
  :added_date,
  :is_primary_region)
  SENSITIVE = []
  include Aws::Structure
end

#region_nameString

The Amazon Web Services Region name.

Returns:

  • (String)


1843
1844
1845
1846
1847
1848
1849
1850
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1843

class DescribeRegionResponse < Struct.new(
  :region_name,
  :status,
  :added_date,
  :is_primary_region)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the Region. Valid values are ACTIVE (Region is operational), ADDING (Region replication workflow is in progress), or REMOVING (Region removal workflow is in progress).

Returns:

  • (String)


1843
1844
1845
1846
1847
1848
1849
1850
# File 'lib/aws-sdk-ssoadmin/types.rb', line 1843

class DescribeRegionResponse < Struct.new(
  :region_name,
  :status,
  :added_date,
  :is_primary_region)
  SENSITIVE = []
  include Aws::Structure
end