Class: Aws::SSOAdmin::Types::EncryptionConfigurationDetails

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

The encryption configuration of your IAM Identity Center instance, including the key type, KMS key ARN, and current encryption status.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#encryption_statusString

The current status of encryption configuration.

Returns:

  • (String)


2024
2025
2026
2027
2028
2029
2030
2031
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2024

class EncryptionConfigurationDetails < Struct.new(
  :key_type,
  :kms_key_arn,
  :encryption_status,
  :encryption_status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_status_reasonString

Provides additional context about the current encryption status. This field is particularly useful when the encryption status is UPDATE_FAILED. When encryption configuration update fails, this field contains information about the cause, which may include KMS key access issues, key not found errors, invalid key configuration, key in an invalid state, or a disabled key.

Returns:

  • (String)


2024
2025
2026
2027
2028
2029
2030
2031
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2024

class EncryptionConfigurationDetails < Struct.new(
  :key_type,
  :kms_key_arn,
  :encryption_status,
  :encryption_status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#key_typeString

The type of KMS key used for encryption.

Returns:

  • (String)


2024
2025
2026
2027
2028
2029
2030
2031
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2024

class EncryptionConfigurationDetails < Struct.new(
  :key_type,
  :kms_key_arn,
  :encryption_status,
  :encryption_status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The ARN of the KMS key currently used to encrypt data in your IAM Identity Center instance.

Returns:

  • (String)


2024
2025
2026
2027
2028
2029
2030
2031
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2024

class EncryptionConfigurationDetails < Struct.new(
  :key_type,
  :kms_key_arn,
  :encryption_status,
  :encryption_status_reason)
  SENSITIVE = []
  include Aws::Structure
end