Class: Aws::SSOAdmin::Types::GetInlinePolicyForPermissionSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::GetInlinePolicyForPermissionSetRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance under which the operation will be executed.
-
#permission_set_arn ⇒ String
The ARN of the permission set.
Instance Attribute Details
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance under which the operation will be executed. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
2203 2204 2205 2206 2207 2208 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2203 class GetInlinePolicyForPermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn) SENSITIVE = [] include Aws::Structure end |
#permission_set_arn ⇒ String
The ARN of the permission set.
2203 2204 2205 2206 2207 2208 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2203 class GetInlinePolicyForPermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn) SENSITIVE = [] include Aws::Structure end |