Class: Aws::SSOAdmin::Types::Grant

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure, Aws::Structure::Union
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Note:

Grant is a union - when making an API calls you must set exactly one of the members.

Note:

Grant is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of Grant corresponding to the set member.

The Grant union represents the set of possible configuration options for the selected grant type. Exactly one member of the union must be specified, and must match the grant type selected.

Defined Under Namespace

Classes: AuthorizationCode, JwtBearer, RefreshToken, TokenExchange, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authorization_codeTypes::AuthorizationCodeGrant

Configuration options for the ‘authorization_code` grant type.



2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2286

class Grant < Struct.new(
  :authorization_code,
  :jwt_bearer,
  :refresh_token,
  :token_exchange,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AuthorizationCode < Grant; end
  class JwtBearer < Grant; end
  class RefreshToken < Grant; end
  class TokenExchange < Grant; end
  class Unknown < Grant; end
end

#jwt_bearerTypes::JwtBearerGrant

Configuration options for the ‘urn:ietf:params:oauth:grant-type:jwt-bearer` grant type.



2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2286

class Grant < Struct.new(
  :authorization_code,
  :jwt_bearer,
  :refresh_token,
  :token_exchange,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AuthorizationCode < Grant; end
  class JwtBearer < Grant; end
  class RefreshToken < Grant; end
  class TokenExchange < Grant; end
  class Unknown < Grant; end
end

#refresh_tokenTypes::RefreshTokenGrant

Configuration options for the ‘refresh_token` grant type.



2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2286

class Grant < Struct.new(
  :authorization_code,
  :jwt_bearer,
  :refresh_token,
  :token_exchange,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AuthorizationCode < Grant; end
  class JwtBearer < Grant; end
  class RefreshToken < Grant; end
  class TokenExchange < Grant; end
  class Unknown < Grant; end
end

#token_exchangeTypes::TokenExchangeGrant

Configuration options for the ‘urn:ietf:params:oauth:grant-type:token-exchange` grant type.



2286
2287
2288
2289
2290
2291
2292
2293
2294
2295
2296
2297
2298
2299
2300
2301
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2286

class Grant < Struct.new(
  :authorization_code,
  :jwt_bearer,
  :refresh_token,
  :token_exchange,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AuthorizationCode < Grant; end
  class JwtBearer < Grant; end
  class RefreshToken < Grant; end
  class TokenExchange < Grant; end
  class Unknown < Grant; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



2286
2287
2288
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2286

def unknown
  @unknown
end