Class: Aws::SSOAdmin::Types::InstanceMetadata

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Provides information about the IAM Identity Center instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_dateTime

The date and time that the Identity Center instance was created.

Returns:

  • (Time)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2368

class InstanceMetadata < Struct.new(
  :instance_arn,
  :identity_store_id,
  :owner_account_id,
  :name,
  :created_date,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#identity_store_idString

The identifier of the identity store that is connected to the Identity Center instance.

Returns:

  • (String)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2368

class InstanceMetadata < Struct.new(
  :instance_arn,
  :identity_store_id,
  :owner_account_id,
  :name,
  :created_date,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#instance_arnString

The ARN of the Identity Center instance under which the operation will be executed. For more information about ARNs, see [Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces](/general/latest/gr/aws-arns-and-namespaces.html) in the *Amazon Web Services General Reference*.

Returns:

  • (String)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2368

class InstanceMetadata < Struct.new(
  :instance_arn,
  :identity_store_id,
  :owner_account_id,
  :name,
  :created_date,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Identity Center instance.

Returns:

  • (String)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2368

class InstanceMetadata < Struct.new(
  :instance_arn,
  :identity_store_id,
  :owner_account_id,
  :name,
  :created_date,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#owner_account_idString

The Amazon Web Services account ID number of the owner of the Identity Center instance.

Returns:

  • (String)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2368

class InstanceMetadata < Struct.new(
  :instance_arn,
  :identity_store_id,
  :owner_account_id,
  :name,
  :created_date,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of this Identity Center instance.

Returns:

  • (String)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2368

class InstanceMetadata < Struct.new(
  :instance_arn,
  :identity_store_id,
  :owner_account_id,
  :name,
  :created_date,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end

#status_reasonString

Provides additional context about the current status of the IAM Identity Center instance. This field is particularly useful when an instance is in a non-ACTIVE state, such as CREATE_FAILED. When an instance creation fails, this field contains information about the cause, which may include issues with KMS key configuration or insufficient permissions.

Returns:

  • (String)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2368

class InstanceMetadata < Struct.new(
  :instance_arn,
  :identity_store_id,
  :owner_account_id,
  :name,
  :created_date,
  :status,
  :status_reason)
  SENSITIVE = []
  include Aws::Structure
end