Class: Aws::SSOAdmin::Types::JwtBearerGrant
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::JwtBearerGrant
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
A structure that defines configuration settings for an application
that supports the JWT Bearer Token Authorization Grant. The
AuthorizedAudience field is the aud claim. For more information, see
RFC 7523.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorized_token_issuers ⇒ Array<Types::AuthorizedTokenIssuer>
A list of allowed token issuers trusted by the Identity Center instances for this application.
Instance Attribute Details
#authorized_token_issuers ⇒ Array<Types::AuthorizedTokenIssuer>
A list of allowed token issuers trusted by the Identity Center instances for this application.
AuthorizedTokenIssuers is required when the grant type is
JwtBearerGrant.
2454 2455 2456 2457 2458 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2454 class JwtBearerGrant < Struct.new( :authorized_token_issuers) SENSITIVE = [] include Aws::Structure end |