Class: Aws::SSOAdmin::Types::ListApplicationAuthenticationMethodsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::ListApplicationAuthenticationMethodsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_arn ⇒ String
Specifies the ARN of the application with the authentication methods you want to list.
-
#next_token ⇒ String
Specifies that you want to receive the next page of results.
Instance Attribute Details
#application_arn ⇒ String
Specifies the ARN of the application with the authentication methods you want to list.
2942 2943 2944 2945 2946 2947 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2942 class ListApplicationAuthenticationMethodsRequest < Struct.new( :application_arn, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Specifies that you want to receive the next page of results. Valid only if you received a NextToken response in the previous request. If you did, it indicates that more output is available. Set this parameter to the value provided by the previous call’s NextToken response to request the next page of results.
2942 2943 2944 2945 2946 2947 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 2942 class ListApplicationAuthenticationMethodsRequest < Struct.new( :application_arn, :next_token) SENSITIVE = [] include Aws::Structure end |