Class: Aws::SSOAdmin::Types::ListCustomerManagedPolicyReferencesInPermissionSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::ListCustomerManagedPolicyReferencesInPermissionSetRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance under which the operation will be executed.
-
#max_results ⇒ Integer
The maximum number of results to display for the list call.
-
#next_token ⇒ String
The pagination token for the list API.
-
#permission_set_arn ⇒ String
The ARN of the
PermissionSet.
Instance Attribute Details
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance under which the operation will be executed.
3172 3173 3174 3175 3176 3177 3178 3179 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3172 class ListCustomerManagedPolicyReferencesInPermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to display for the list call.
3172 3173 3174 3175 3176 3177 3178 3179 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3172 class ListCustomerManagedPolicyReferencesInPermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token for the list API. Initially the value is null. Use the output of previous API calls to make subsequent calls.
3172 3173 3174 3175 3176 3177 3178 3179 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3172 class ListCustomerManagedPolicyReferencesInPermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#permission_set_arn ⇒ String
The ARN of the PermissionSet.
3172 3173 3174 3175 3176 3177 3178 3179 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3172 class ListCustomerManagedPolicyReferencesInPermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |