Class: Aws::SSOAdmin::Types::ListManagedPoliciesInPermissionSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::ListManagedPoliciesInPermissionSetRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance under which the operation will be executed.
-
#max_results ⇒ Integer
The maximum number of results to display for the PermissionSet.
-
#next_token ⇒ String
The pagination token for the list API.
-
#permission_set_arn ⇒ String
The ARN of the PermissionSet whose managed policies will be listed.
Instance Attribute Details
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance under which the operation will be executed. For more information about ARNs, see [Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces](/general/latest/gr/aws-arns-and-namespaces.html) in the *Amazon Web Services General Reference*.
3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3260 class ListManagedPoliciesInPermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to display for the PermissionSet.
3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3260 class ListManagedPoliciesInPermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token for the list API. Initially the value is null. Use the output of previous API calls to make subsequent calls.
3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3260 class ListManagedPoliciesInPermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#permission_set_arn ⇒ String
The ARN of the PermissionSet whose managed policies will be listed.
3260 3261 3262 3263 3264 3265 3266 3267 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3260 class ListManagedPoliciesInPermissionSetRequest < Struct.new( :instance_arn, :permission_set_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |