Class: Aws::SSOAdmin::Types::ListPermissionSetProvisioningStatusRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::ListPermissionSetProvisioningStatusRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Types::OperationStatusFilter
Filters results based on the passed attribute value.
-
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance under which the operation will be executed.
-
#max_results ⇒ Integer
The maximum number of results to display for the assignment.
-
#next_token ⇒ String
The pagination token for the list API.
Instance Attribute Details
#filter ⇒ Types::OperationStatusFilter
Filters results based on the passed attribute value.
3310 3311 3312 3313 3314 3315 3316 3317 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3310 class ListPermissionSetProvisioningStatusRequest < Struct.new( :instance_arn, :max_results, :next_token, :filter) SENSITIVE = [] include Aws::Structure end |
#instance_arn ⇒ String
The ARN of the IAM Identity Center instance under which the operation will be executed. For more information about ARNs, see [Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces](/general/latest/gr/aws-arns-and-namespaces.html) in the *Amazon Web Services General Reference*.
3310 3311 3312 3313 3314 3315 3316 3317 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3310 class ListPermissionSetProvisioningStatusRequest < Struct.new( :instance_arn, :max_results, :next_token, :filter) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to display for the assignment.
3310 3311 3312 3313 3314 3315 3316 3317 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3310 class ListPermissionSetProvisioningStatusRequest < Struct.new( :instance_arn, :max_results, :next_token, :filter) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token for the list API. Initially the value is null. Use the output of previous API calls to make subsequent calls.
3310 3311 3312 3313 3314 3315 3316 3317 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3310 class ListPermissionSetProvisioningStatusRequest < Struct.new( :instance_arn, :max_results, :next_token, :filter) SENSITIVE = [] include Aws::Structure end |