Class: Aws::SSOAdmin::Types::ListRegionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::ListRegionsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM Identity Center instance.
-
#max_results ⇒ Integer
The maximum number of results to return in a single call.
-
#next_token ⇒ String
The pagination token for the list API.
Instance Attribute Details
#instance_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM Identity Center instance.
3454 3455 3456 3457 3458 3459 3460 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3454 class ListRegionsRequest < Struct.new( :instance_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in a single call. Default is 100.
3454 3455 3456 3457 3458 3459 3460 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3454 class ListRegionsRequest < Struct.new( :instance_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token for the list API. Initially the value is null. Use the output of previous API calls to make subsequent calls.
3454 3455 3456 3457 3458 3459 3460 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 3454 class ListRegionsRequest < Struct.new( :instance_arn, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |