Class: Aws::SSOAdmin::Types::RegionMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::RegionMetadata
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Contains information about an enabled Region of an IAM Identity Center instance, including the Region name, status, date added, and whether it is the primary Region.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#added_date ⇒ Time
The timestamp when the Region was added to the IAM Identity Center instance.
-
#is_primary_region ⇒ Boolean
Indicates whether this is the primary Region where the IAM Identity Center instance was originally enabled.
-
#region_name ⇒ String
The Amazon Web Services Region name.
-
#status ⇒ String
The current status of the Region.
Instance Attribute Details
#added_date ⇒ Time
The timestamp when the Region was added to the IAM Identity Center instance. For the primary Region, this is the instance creation time.
4162 4163 4164 4165 4166 4167 4168 4169 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4162 class RegionMetadata < Struct.new( :region_name, :status, :added_date, :is_primary_region) SENSITIVE = [] include Aws::Structure end |
#is_primary_region ⇒ Boolean
Indicates whether this is the primary Region where the IAM Identity Center instance was originally enabled. The primary Region cannot be removed.
4162 4163 4164 4165 4166 4167 4168 4169 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4162 class RegionMetadata < Struct.new( :region_name, :status, :added_date, :is_primary_region) SENSITIVE = [] include Aws::Structure end |
#region_name ⇒ String
The Amazon Web Services Region name.
4162 4163 4164 4165 4166 4167 4168 4169 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4162 class RegionMetadata < Struct.new( :region_name, :status, :added_date, :is_primary_region) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the Region. Valid values are ACTIVE (Region is operational), ADDING (Region extension workflow is in progress), or REMOVING (Region removal workflow is in progress).
4162 4163 4164 4165 4166 4167 4168 4169 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4162 class RegionMetadata < Struct.new( :region_name, :status, :added_date, :is_primary_region) SENSITIVE = [] include Aws::Structure end |