Class: Aws::SSOAdmin::Types::RemoveRegionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::RemoveRegionResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ String
The status of the Region after the remove operation.
Instance Attribute Details
#status ⇒ String
The status of the Region after the remove operation. The status is REMOVING when the asynchronous workflow is in progress. The Region record is deleted when the workflow completes.
4199 4200 4201 4202 4203 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4199 class RemoveRegionResponse < Struct.new( :status) SENSITIVE = [] include Aws::Structure end |