Class: Aws::SSOAdmin::Types::UpdateApplicationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#application_arnString

Specifies the ARN of the application. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.

Returns:

  • (String)


4557
4558
4559
4560
4561
4562
4563
4564
4565
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4557

class UpdateApplicationRequest < Struct.new(
  :application_arn,
  :name,
  :description,
  :status,
  :portal_options)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the .

Returns:

  • (String)


4557
4558
4559
4560
4561
4562
4563
4564
4565
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4557

class UpdateApplicationRequest < Struct.new(
  :application_arn,
  :name,
  :description,
  :status,
  :portal_options)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Specifies the updated name for the application.

Returns:

  • (String)


4557
4558
4559
4560
4561
4562
4563
4564
4565
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4557

class UpdateApplicationRequest < Struct.new(
  :application_arn,
  :name,
  :description,
  :status,
  :portal_options)
  SENSITIVE = []
  include Aws::Structure
end

#portal_optionsTypes::UpdateApplicationPortalOptions

A structure that describes the options for the portal associated with an application.



4557
4558
4559
4560
4561
4562
4563
4564
4565
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4557

class UpdateApplicationRequest < Struct.new(
  :application_arn,
  :name,
  :description,
  :status,
  :portal_options)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

Specifies whether the application is enabled or disabled.

Returns:

  • (String)


4557
4558
4559
4560
4561
4562
4563
4564
4565
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4557

class UpdateApplicationRequest < Struct.new(
  :application_arn,
  :name,
  :description,
  :status,
  :portal_options)
  SENSITIVE = []
  include Aws::Structure
end