Class: Aws::SSOAdmin::Types::UpdateApplicationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::UpdateApplicationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#application_arn ⇒ String
Specifies the ARN of the application.
-
#description ⇒ String
The description of the .
-
#name ⇒ String
Specifies the updated name for the application.
-
#portal_options ⇒ Types::UpdateApplicationPortalOptions
A structure that describes the options for the portal associated with an application.
-
#status ⇒ String
Specifies whether the application is enabled or disabled.
Instance Attribute Details
#application_arn ⇒ String
Specifies the ARN of the application. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
4557 4558 4559 4560 4561 4562 4563 4564 4565 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4557 class UpdateApplicationRequest < Struct.new( :application_arn, :name, :description, :status, :portal_options) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the .
4557 4558 4559 4560 4561 4562 4563 4564 4565 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4557 class UpdateApplicationRequest < Struct.new( :application_arn, :name, :description, :status, :portal_options) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Specifies the updated name for the application.
4557 4558 4559 4560 4561 4562 4563 4564 4565 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4557 class UpdateApplicationRequest < Struct.new( :application_arn, :name, :description, :status, :portal_options) SENSITIVE = [] include Aws::Structure end |
#portal_options ⇒ Types::UpdateApplicationPortalOptions
A structure that describes the options for the portal associated with an application.
4557 4558 4559 4560 4561 4562 4563 4564 4565 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4557 class UpdateApplicationRequest < Struct.new( :application_arn, :name, :description, :status, :portal_options) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Specifies whether the application is enabled or disabled.
4557 4558 4559 4560 4561 4562 4563 4564 4565 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4557 class UpdateApplicationRequest < Struct.new( :application_arn, :name, :description, :status, :portal_options) SENSITIVE = [] include Aws::Structure end |