Class: Aws::SSOAdmin::Types::UpdateInstanceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::UpdateInstanceRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encryption_configuration ⇒ Types::EncryptionConfiguration
Specifies the encryption configuration for your IAM Identity Center instance.
-
#instance_arn ⇒ String
The ARN of the instance of IAM Identity Center under which the operation will run.
-
#name ⇒ String
Updates the instance name.
-
#permission_sets_enabled ⇒ Boolean
Enables permission sets for this Identity Center instance.
Instance Attribute Details
#encryption_configuration ⇒ Types::EncryptionConfiguration
Specifies the encryption configuration for your IAM Identity Center instance. You can use this to configure customer managed KMS keys or Amazon Web Services owned KMS keys for encrypting your instance data.
4626 4627 4628 4629 4630 4631 4632 4633 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4626 class UpdateInstanceRequest < Struct.new( :name, :instance_arn, :encryption_configuration, :permission_sets_enabled) SENSITIVE = [] include Aws::Structure end |
#instance_arn ⇒ String
The ARN of the instance of IAM Identity Center under which the operation will run. For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces in the Amazon Web Services General Reference.
4626 4627 4628 4629 4630 4631 4632 4633 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4626 class UpdateInstanceRequest < Struct.new( :name, :instance_arn, :encryption_configuration, :permission_sets_enabled) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Updates the instance name.
4626 4627 4628 4629 4630 4631 4632 4633 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4626 class UpdateInstanceRequest < Struct.new( :name, :instance_arn, :encryption_configuration, :permission_sets_enabled) SENSITIVE = [] include Aws::Structure end |
#permission_sets_enabled ⇒ Boolean
Enables permission sets for this Identity Center instance. The only
accepted value is true . After permission sets are enabled, they
cannot be disabled.
EncryptionConfiguration and PermissionSetsEnabled
in the same request. To configure both, make two separate
UpdateInstance calls. These calls can be made in parallel.
4626 4627 4628 4629 4630 4631 4632 4633 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4626 class UpdateInstanceRequest < Struct.new( :name, :instance_arn, :encryption_configuration, :permission_sets_enabled) SENSITIVE = [] include Aws::Structure end |