Class: Aws::SSOAdmin::Types::UpdateInstanceRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SSOAdmin::Types::UpdateInstanceRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-ssoadmin/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#encryption_configuration ⇒ Types::EncryptionConfiguration
Specifies the encryption configuration for your IAM Identity Center instance.
-
#instance_arn ⇒ String
The ARN of the instance of IAM Identity Center under which the operation will run.
-
#name ⇒ String
Updates the instance name.
Instance Attribute Details
#encryption_configuration ⇒ Types::EncryptionConfiguration
Specifies the encryption configuration for your IAM Identity Center instance. You can use this to configure customer managed KMS keys or Amazon Web Services owned KMS keys for encrypting your instance data.
4596 4597 4598 4599 4600 4601 4602 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4596 class UpdateInstanceRequest < Struct.new( :name, :instance_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#instance_arn ⇒ String
The ARN of the instance of IAM Identity Center under which the operation will run. For more information about ARNs, see [Amazon Resource Names (ARNs) and Amazon Web Services Service Namespaces](/general/latest/gr/aws-arns-and-namespaces.html) in the *Amazon Web Services General Reference*.
4596 4597 4598 4599 4600 4601 4602 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4596 class UpdateInstanceRequest < Struct.new( :name, :instance_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Updates the instance name.
4596 4597 4598 4599 4600 4601 4602 |
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4596 class UpdateInstanceRequest < Struct.new( :name, :instance_arn, :encryption_configuration) SENSITIVE = [] include Aws::Structure end |