Class: Aws::SSOAdmin::Types::UpdateTrustedTokenIssuerRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-ssoadmin/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

Specifies the updated name to be applied to the trusted token issuer configuration.

Returns:

  • (String)


4700
4701
4702
4703
4704
4705
4706
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4700

class UpdateTrustedTokenIssuerRequest < Struct.new(
  :trusted_token_issuer_arn,
  :name,
  :trusted_token_issuer_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#trusted_token_issuer_arnString

Specifies the ARN of the trusted token issuer configuration that you want to update.

Returns:

  • (String)


4700
4701
4702
4703
4704
4705
4706
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4700

class UpdateTrustedTokenIssuerRequest < Struct.new(
  :trusted_token_issuer_arn,
  :name,
  :trusted_token_issuer_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#trusted_token_issuer_configurationTypes::TrustedTokenIssuerUpdateConfiguration

Specifies a structure with settings to apply to the specified trusted token issuer. The settings that you can provide are determined by the type of the trusted token issuer that you are updating.



4700
4701
4702
4703
4704
4705
4706
# File 'lib/aws-sdk-ssoadmin/types.rb', line 4700

class UpdateTrustedTokenIssuerRequest < Struct.new(
  :trusted_token_issuer_arn,
  :name,
  :trusted_token_issuer_configuration)
  SENSITIVE = []
  include Aws::Structure
end